<?php
/* THIS IS A GENERATED FILE. DO NOT EDIT DIRECTLY. */
$generated_i18n_strings = array(
	// Reference: src/App.vue:238
	// Reference: src/views/Setup.vue:1647
	__( 'Changes not saved, are you sure you want to leave?', 'coming-soon' ),

	// Reference: src/admin/Aboutus.vue:36
	// Reference: src/admin/App.vue:300
	__( 'About Us', 'coming-soon' ),

	// Reference: src/admin/Aboutus.vue:37
	__( 'Getting Started', 'coming-soon' ),

	// Reference: src/admin/Aboutus.vue:38
	__( 'Lite vs Pro', 'coming-soon' ),

	// Reference: src/admin/AboutusAbout.vue:103
	__( 'Yup, we know a thing or two about building awesome products that customers love.', 'coming-soon' ),

	// Reference: src/admin/AboutusAbout.vue:107
	__( 'the most popular lead-generation software', 'coming-soon' ),

	// Reference: src/admin/AboutusAbout.vue:111
	__( 'the best WordPress analytics plugin', 'coming-soon' ),

	// Reference: src/admin/AboutusAbout.vue:115
	__( 'the best WordPress forms plugin', 'coming-soon' ),

	// Reference: src/admin/AboutusAbout.vue:119
	__( 'the best WordPress giveaway plugin', 'coming-soon' ),

	// Reference: src/admin/AboutusAbout.vue:123
	__( 'and finally the best WordPress FOMO plugin', 'coming-soon' ),

	// Reference: src/admin/AboutusAbout.vue:127
	__( 'SeedProd Team photo', 'coming-soon' ),

	// Reference: src/admin/AboutusAbout.vue:128
	__( 'The SeedProd Team', 'coming-soon' ),

	// Reference: src/admin/AboutusAbout.vue:87
	__( 'Hello and welcome to SeedProd, the most beginner friendly drag & drop WordPress landing page plugin. At SeedProd, we build software that helps you create beautiful responsive landing pages for your website in minutes.', 'coming-soon' ),

	// Reference: src/admin/AboutusAbout.vue:91
	__( 'Over the years, we found that most WordPress landing page plugins were bloated, buggy, slow, and very hard to use. So we started with a simple goal: build a WordPress landing page plugin that’s both easy and powerful.', 'coming-soon' ),

	// Reference: src/admin/AboutusAbout.vue:95
	__( 'Our goal is to take the pain out of creating landing pages and make it easy.', 'coming-soon' ),

	// Reference: src/admin/AboutusAbout.vue:99
	__( 'SeedProd is brought to you by the same team that’s behind the largest WordPress resource site,', 'coming-soon' ),

	// Reference: src/admin/App.vue:298
	__( 'Pages', 'coming-soon' ),

	// Reference: src/admin/App.vue:299
	__( 'Growth Tools', 'coming-soon' ),

	// Reference: src/admin/App.vue:301
	// Reference: src/admin/Dashboard-Lite.vue:644
	__( 'Subscribers', 'coming-soon' ),

	// Reference: src/admin/App.vue:302
	// Reference: src/components/CountdownOptions.vue:848
	// Reference: src/components/CustomHTMLOptions.vue:199
	// Reference: src/components/FormOptions.vue:178
	// Reference: src/components/NavOptions.vue:570
	// Reference: src/components/PostsOptions.vue:1454
	// Reference: src/components/ProductRelatedOptions.vue:604
	// Reference: src/components/ShortcodeOptions.vue:143
	// Reference: src/components/TemplatetagOptions.vue:123
	// Reference: src/components/UpsellsOptions.vue:604
	// Reference: src/components/WCAddToCartOptions.vue:733
	// Reference: src/components/WCCustomProductsGridOptions.vue:1075
	__( 'Settings', 'coming-soon' ),

	// Reference: src/admin/App.vue:303
	__( 'SeedProd Logo', 'coming-soon' ),

	// Reference: src/admin/App.vue:304
	__( 'Previous message ', 'coming-soon' ),

	// Reference: src/admin/App.vue:305
	__( 'Next message', 'coming-soon' ),

	// Reference: src/admin/App.vue:306
	__( 'Theme Builder', 'coming-soon' ),

	// Reference: src/admin/App.vue:307
	__( 'Import / Export', 'coming-soon' ),

	// Reference: src/admin/App.vue:308
	__( 'Setup', 'coming-soon' ),

	// Reference: src/admin/App.vue:309
	__( 'Theme Template Kit Chooser', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:1009
	// Reference: src/admin/Subscribers-Lite.vue:403
	__( 'Are you sure?', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:1015
	__( 'Yes, empty trash!', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:1039
	__( 'Pages Deleted!', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:1069
	__( 'Page Duplicated', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:615
	__( 'Coming Soon Mode', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:616
	__( 'Search Landing Pages', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:617
	__( 'The Coming Soon Page will be available to search engines if your site is not private.', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:621
	__( 'Set up a Coming Soon Page', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:622
	// Reference: src/admin/Setup-Lite.vue:874
	__( 'Edit Page', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:623
	// Reference: src/views/Setup.vue:1032
	__( 'Preview', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:624
	// Reference: src/components/ProductDataTabsOptions.vue:325
	__( 'Active', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:625
	__( 'Inactive', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:626
	__( 'Maintenance Mode', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:627
	__( 'The Maintenance Mode Page will notify search engines that the site is unavailable.', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:631
	__( 'Set up a Maintenance Mode Page', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:635
	// Reference: src/admin/Subscribers-Lite.vue:256
	__( '404 Page', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:636
	__( 'Replace your default theme 404 page with a custom high converting 404 page.', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:640
	__( 'Set up a 404 Page', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:641
	// Reference: src/admin/Subscribers-Lite.vue:257
	__( 'Landing Pages', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:642
	__( 'Add New Landing Page', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:643
	// Reference: src/components/TypographyControl.vue:275
	__( 'Edit', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:645
	// Reference: src/components/PostinfoOptions.vue:602
	// Reference: src/components/ProductMetaOptions.vue:337
	__( 'Duplicate', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:648
	__( 'Last Modified', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:649
	__( 'You do not have any landing pages yet.', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:653
	__( 'Create New Landing Page', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:656
	__( 'SeedProd Coming Soon Page', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:657
	__( 'SeedProd Maintenance Page', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:658
	__( 'SeedProd 404 Page', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:659
	__( 'Create Optin, Sales, Webinar, Thank You or any type of Landing Page you need.', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:663
	// Reference: src/admin/Subscribers-Lite.vue:266
	__( 'Login Page', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:664
	__( 'Create a Custom Login Page for your website. Optionally replace the default login page.', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:665
	__( 'Set up a Login Page', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:666
	__( 'SeedProd Login Page', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:685
	// Reference: src/admin/ThemeChooser.vue:801
	// Reference: src/views/TemplateChooser-Lite.vue:1214
	__( 'All', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:689
	__( 'Published', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:693
	__( 'Drafts', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:702
	__( 'Trash', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:709
	__( 'Move To Trash', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:713
	__( 'Restore', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:717
	__( 'Delete Permanently', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:722
	// Reference: src/admin/Subscribers-Lite.vue:308
	// Reference: src/components/AnchorOptions.vue:77
	// Reference: src/components/PostauthorboxOptions.vue:336
	// Reference: src/components/TestimonialOptions.vue:547
	__( 'Name', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:727
	__( 'URL', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:732
	// Reference: src/components/PostinfoOptions.vue:572
	// Reference: src/components/PostsOptions.vue:1475
	// Reference: src/components/ProductRelatedOptions.vue:652
	// Reference: src/components/UpsellsOptions.vue:652
	// Reference: src/components/WCCustomProductsGridOptions.vue:1190
	__( 'Date', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:744
	// Reference: src/admin/Subscribers-Lite.vue:331
	// Reference: src/components/ListTable.vue:468
	__( 'Loading', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:957
	__( 'Pages Moved to Trash.', 'coming-soon' ),

	// Reference: src/admin/Dashboard-Lite.vue:990
	__( 'Pages Restored.', 'coming-soon' ),

	// Reference: src/admin/GrowthTools.vue:539
	// Reference: src/components/ContactForm.vue:169
	// Reference: src/components/Giveaway.vue:170
	// Reference: src/views/SettingsAnalytics.vue:131
	// Reference: src/views/SettingsSEO.vue:242
	__( 'Install', 'coming-soon' ),

	// Reference: src/admin/GrowthTools.vue:542
	__( 'Deactivate', 'coming-soon' ),

	// Reference: src/admin/GrowthTools.vue:545
	// Reference: src/components/ContactForm.vue:170
	// Reference: src/components/Giveaway.vue:171
	// Reference: src/views/SettingsAnalytics.vue:132
	// Reference: src/views/SettingsSEO.vue:243
	__( 'Activate', 'coming-soon' ),

	// Reference: src/admin/GrowthTools.vue:81
	// Reference: src/admin/Popups.vue:126
	__( 'Status', 'coming-soon' ),

	// Reference: src/admin/GrowthTools.vue:82
	__( 'PRO Version installed', 'coming-soon' ),

	// Reference: src/admin/Popups.vue:383
	__( 'Get OptinMonster Now', 'coming-soon' ),

	// Reference: src/admin/Popups.vue:386
	__( 'OptinMonster is Active - Go to Settings', 'coming-soon' ),

	// Reference: src/admin/Popups.vue:390
	__( 'Activate OptinMonster', 'coming-soon' ),

	// Reference: src/admin/Popups.vue:392
	__( 'Activating OptinMonster', 'coming-soon' ),

	// Reference: src/admin/Settings.vue:19
	// Reference: src/components/WCCustomProductsGridOptions.vue:1153
	// Reference: src/views/SettingsGeneral.vue:231
	// Reference: src/views/SetupSettings.vue:253
	__( 'General', 'coming-soon' ),

	// Reference: src/admin/Settings.vue:20
	__( 'Emails', 'coming-soon' ),

	// Reference: src/admin/Settings.vue:21
	__( 'Integrations', 'coming-soon' ),

	// Reference: src/admin/SettingsGeneral.vue:239
	__( 'License', 'coming-soon' ),

	// Reference: src/admin/SettingsGeneral.vue:240
	__( 'Your license key provides access to updates and addons.', 'coming-soon' ),

	// Reference: src/admin/SettingsGeneral.vue:241
	__( 'You\'re using <strong>SeedProd Lite</strong> - No License needed. Enjoy!', 'coming-soon' ),

	// Reference: src/admin/SettingsGeneral.vue:242
	__( 'To unlock more features consider <a href=\'%s\' target=\'_blank\'>upgrading to PRO</a> . As a valued SeedProd Lite user you\'ll receive <strong>a discount off the regular price</strong>, automatically applied at checkout! ', 'coming-soon' ),

	// Reference: src/admin/SettingsGeneral.vue:243
	__( 'If you already have a license key for <a href=\'%s\' target=\'_blank\'>SeedProd Lite</a>, please enter it to Upgrade to the Pro Features. An External Service will be used to verify and connect you to SeedProd.', 'coming-soon' ),

	// Reference: src/admin/SettingsGeneral.vue:244
	__( 'License Key', 'coming-soon' ),

	// Reference: src/admin/SettingsGeneral.vue:245
	__( 'Enter Your License Key Here', 'coming-soon' ),

	// Reference: src/admin/SettingsGeneral.vue:246
	__( 'Recheck Key', 'coming-soon' ),

	// Reference: src/admin/SettingsGeneral.vue:247
	__( 'Verify Key', 'coming-soon' ),

	// Reference: src/admin/SettingsGeneral.vue:248
	__( 'Deactivate Key', 'coming-soon' ),

	// Reference: src/admin/SettingsGeneral.vue:249
	__( 'Connect to SeedProd to install the Pro Version', 'coming-soon' ),

	// Reference: src/admin/SettingsGeneral.vue:250
	__( 'You currently have the <strong>%s</strong> license.', 'coming-soon' ),

	// Reference: src/admin/SettingsGeneral.vue:252
	__( 'Debug Information', 'coming-soon' ),

	// Reference: src/admin/SettingsGeneral.vue:253
	__( 'Facebook APP ID', 'coming-soon' ),

	// Reference: src/admin/SettingsGeneral.vue:254
	// Reference: src/views/SetupDesign-Lite.vue:731
	__( 'Global Settings', 'coming-soon' ),

	// Reference: src/admin/SettingsGeneral.vue:256
	__( 'Save Settings', 'coming-soon' ),

	// Reference: src/admin/SettingsGeneral.vue:257
	__( 'Disable Edit SeedProd Button', 'coming-soon' ),

	// Reference: src/admin/SettingsGeneral.vue:258
	__( 'Enable Usage Tracking', 'coming-soon' ),

	// Reference: src/admin/SettingsGeneral.vue:259
	// Reference: src/components/BusinessHoursOptions.vue:742
	// Reference: src/components/TestimonialOptions.vue:552
	// Reference: src/views/SettingsAccess-Lite.vue:322
	__( 'Yes', 'coming-soon' ),

	// Reference: src/admin/SettingsGeneral.vue:260
	// Reference: src/components/BusinessHoursOptions.vue:743
	// Reference: src/components/TestimonialOptions.vue:553
	// Reference: src/views/SettingsAccess-Lite.vue:323
	__( 'No', 'coming-soon' ),

	// Reference: src/admin/SettingsGeneral.vue:383
	// Reference: src/views/TemplateChooser-Lite.vue:1908
	__( 'Could not be saved. Please contact Support if you continue to experience this issue.', 'coming-soon' ),

	// Reference: src/admin/SettingsGeneral.vue:448
	// Reference: src/views/Setup.vue:1541
	__( 'Saved!', 'coming-soon' ),

	// Reference: src/admin/SettingsGeneral.vue:469
	__( 'Looks like you don\'t have permission to save.', 'coming-soon' ),

	// Reference: src/admin/Setup-Lite.vue:853
	__( '<h1 class=\'sp-text-2xl sp-text-neutral sp-m-0 sp-mb-4 sp-font-bold\'>Template Setup Complete</h1>', 'coming-soon' ),

	// Reference: src/admin/Setup-Lite.vue:854
	__( 'You can close this window and get started editing you page<br> or setup a new page.', 'coming-soon' ),

	// Reference: src/admin/Setup-Lite.vue:855
	// Reference: src/components/ColorPicker.vue:266
	// Reference: src/components/CustomHTMLOptions.vue:203
	// Reference: src/components/TypographyControl.vue:276
	// Reference: src/views/GlobalCSS.vue:1907
	// Reference: src/views/Setup.vue:1020
	// Reference: src/views/SetupDesign-Lite.vue:741
	__( 'Close', 'coming-soon' ),

	// Reference: src/admin/Setup-Lite.vue:856
	__( 'Click the button below to install and activate the following free plugins:', 'coming-soon' ),

	// Reference: src/admin/Setup-Lite.vue:857
	__( 'Install and Activate Plugins', 'coming-soon' ),

	// Reference: src/admin/Setup-Lite.vue:858
	__( 'I\'ll do it later', 'coming-soon' ),

	// Reference: src/admin/Setup-Lite.vue:864
	__( '<h1 class="sp-text-2xl sp-text-neutral sp-m-0 sp-mb-4 sp-font-bold">Finishing Up!</h1><p class="sp-text-sm sp-text-neutral sp-font-normal">Please do not refresh or exit this page<br>until this process is complete.<p>', 'coming-soon' ),

	// Reference: src/admin/Setup-Lite.vue:869
	__( 'Setup a Coming Soon Page', 'coming-soon' ),

	// Reference: src/admin/Setup-Lite.vue:870
	__( 'A Coming Soon Page will hide your site from public but you\'ll still be able to see it and work on it if logged in.', 'coming-soon' ),

	// Reference: src/admin/Setup-Lite.vue:876
	__( 'Setup a Maintenance Page', 'coming-soon' ),

	// Reference: src/admin/Setup-Lite.vue:877
	__( 'A Maintenance Page will notify search engines that the site is unavailable.', 'coming-soon' ),

	// Reference: src/admin/Setup-Lite.vue:881
	__( 'Setup a Landing Page', 'coming-soon' ),

	// Reference: src/admin/Setup-Lite.vue:882
	__( 'Landing Pages are meant to be standalone pages seperate from the design of your site and theme.', 'coming-soon' ),

	// Reference: src/admin/Setup-Lite.vue:886
	__( 'Edit Landing Pages', 'coming-soon' ),

	// Reference: src/admin/Setup-Lite.vue:887
	__( 'Build a Website', 'coming-soon' ),

	// Reference: src/admin/Setup-Lite.vue:888
	__( 'Build your enite Website. Create Headers, Footers, Pages, Posts, Archives, Sidebars, and more.', 'coming-soon' ),

	// Reference: src/admin/Setup-Lite.vue:892
	__( 'Select a Theme for my Website', 'coming-soon' ),

	// Reference: src/admin/Setup-Lite.vue:896
	__( 'Edit Theme', 'coming-soon' ),

	// Reference: src/admin/Setup-Lite.vue:897
	__( 'Build a WooCommerce Store', 'coming-soon' ),

	// Reference: src/admin/Setup-Lite.vue:898
	__( 'Create an entire WooCommerce store. Customize product pages, checkout, cart, product grids, and more.', 'coming-soon' ),

	// Reference: src/admin/Setup-Lite.vue:902
	__( 'Select a Theme for my Store', 'coming-soon' ),

	// Reference: src/admin/Setup-Lite.vue:903
	__( 'Setup a Login Page', 'coming-soon' ),

	// Reference: src/admin/Setup-Lite.vue:904
	__( 'Create a custom Login page for your website.', 'coming-soon' ),

	// Reference: src/admin/Setup-Lite.vue:908
	__( 'Setup a 404 Page', 'coming-soon' ),

	// Reference: src/admin/Setup-Lite.vue:909
	__( 'Create a custom 404 page for your website.', 'coming-soon' ),

	// Reference: src/admin/Setup-Lite.vue:913
	__( 'Dismiss This Setup Page', 'coming-soon' ),

	// Reference: src/admin/Setup-Lite.vue:914
	__( 'Finish Setup', 'coming-soon' ),

	// Reference: src/admin/Setup-Lite.vue:948
	__( 'There was an issue completing the setup. Please refresh the page and try again.', 'coming-soon' ),

	// Reference: src/admin/Subscribers-Lite.vue:250
	__( 'Subscribers Overview', 'coming-soon' ),

	// Reference: src/admin/Subscribers-Lite.vue:251
	__( 'Export to CSV', 'coming-soon' ),

	// Reference: src/admin/Subscribers-Lite.vue:253
	__( 'All Pages', 'coming-soon' ),

	// Reference: src/admin/Subscribers-Lite.vue:254
	__( 'Coming Soon Page', 'coming-soon' ),

	// Reference: src/admin/Subscribers-Lite.vue:255
	__( 'Maintenance Mode Page', 'coming-soon' ),

	// Reference: src/admin/Subscribers-Lite.vue:258
	__( 'Days', 'coming-soon' ),

	// Reference: src/admin/Subscribers-Lite.vue:260
	__( 'You do not have any subscribers yet.', 'coming-soon' ),

	// Reference: src/admin/Subscribers-Lite.vue:264
	__( 'Go to Pages', 'coming-soon' ),

	// Reference: src/admin/Subscribers-Lite.vue:265
	__( 'Search Emails', 'coming-soon' ),

	// Reference: src/admin/Subscribers-Lite.vue:304
	// Reference: src/components/SocialProfilesOptions.vue:683
	__( 'Email', 'coming-soon' ),

	// Reference: src/admin/Subscribers-Lite.vue:318
	__( 'Created', 'coming-soon' ),

	// Reference: src/admin/Subscribers-Lite.vue:325
	// Reference: src/components/PostinfoOptions.vue:603
	// Reference: src/components/ProductMetaOptions.vue:338
	__( 'Delete', 'coming-soon' ),

	// Reference: src/admin/Subscribers-Lite.vue:441
	__( 'Subscribers Deleted', 'coming-soon' ),

	// Reference: src/admin/Subscribers-Lite.vue:491
	__( 'Exported Started', 'coming-soon' ),

	// Reference: src/admin/ThemeChooser.vue:798
	// Reference: src/views/TemplateChooser-Lite.vue:1208
	__( 'All Templates', 'coming-soon' ),

	// Reference: src/admin/ThemeChooser.vue:799
	// Reference: src/views/TemplateChooser-Lite.vue:1209
	__( 'Favorite Templates', 'coming-soon' ),

	// Reference: src/admin/ThemeChooser.vue:800
	// Reference: src/views/TemplateChooser-Lite.vue:1213
	__( 'Filter:', 'coming-soon' ),

	// Reference: src/admin/ThemeChooser.vue:802
	// Reference: src/views/SectionTemplateOptions-Lite.vue:431
	// Reference: src/views/TemplateChooser-Lite.vue:1215
	__( 'No Templates Found', 'coming-soon' ),

	// Reference: src/admin/ThemeChooser.vue:803
	// Reference: src/components/ImageControl.vue:254
	// Reference: src/views/TemplateChooser-Lite.vue:1229
	__( 'First Page', 'coming-soon' ),

	// Reference: src/admin/ThemeChooser.vue:804
	// Reference: src/components/ImageControl.vue:255
	// Reference: src/views/TemplateChooser-Lite.vue:1230
	__( 'Prev', 'coming-soon' ),

	// Reference: src/admin/ThemeChooser.vue:805
	// Reference: src/components/ImageControl.vue:256
	// Reference: src/views/TemplateChooser-Lite.vue:1231
	__( 'Next', 'coming-soon' ),

	// Reference: src/admin/ThemeChooser.vue:806
	// Reference: src/components/ImageControl.vue:257
	// Reference: src/views/TemplateChooser-Lite.vue:1232
	__( 'Last Page', 'coming-soon' ),

	// Reference: src/admin/ThemeChooser.vue:807
	// Reference: src/views/TemplateChooser-Lite.vue:1233
	__( 'Search templates...', 'coming-soon' ),

	// Reference: src/admin/ThemeChooser.vue:808
	// Reference: src/views/SetupBlockOptions-Lite.vue:1173
	__( 'WooCommerce', 'coming-soon' ),

	// Reference: src/admin/ThemeChooser.vue:809
	__( 'Sort:', 'coming-soon' ),

	// Reference: src/admin/Welcome-Lite.vue:120
	__( 'Thank you for choosing SeedProd - The Best Website Builder, Landing Page Builder, Coming Soon, Maintenance Mode & more...', 'coming-soon' ),

	// Reference: src/admin/Welcome-Lite.vue:124
	__( 'Get Started →', 'coming-soon' ),

	// Reference: src/admin/Welcome-Lite.vue:125
	__( '← Exit Setup', 'coming-soon' ),

	// Reference: src/admin/Welcome-Lite.vue:126
	__( 'Note: You will be transfered to an external service to complete the setup wizard.', 'coming-soon' ),

	// Reference: src/admin/Welcome-Lite.vue:139
	__( 'Use our setup wizard to get started in less than 2 minutes and unlock free templates!', 'coming-soon' ),

	// Reference: src/admin/Welcome-Lite.vue:144
	__( 'Use our setup wizard to get started in less than 2 minutes!', 'coming-soon' ),

	// Reference: src/admin/Welcome-Lite.vue:156
	__( 'Are you sure you want to exit the setup wizard?

You will miss out on our free templates. 😬', 'coming-soon' ),

	// Reference: src/admin/Welcome-Lite.vue:161
	__( 'Are you sure you want to exit the setup wizard? 😬', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue:599
	// Reference: src/components/AddToCartOptions.vue:1066
	// Reference: src/components/AdditionalInformationOptions.vue:127
	// Reference: src/components/BulletListOptions.vue:494
	// Reference: src/components/BusinessHoursOptions.vue:712
	// Reference: src/components/ButtonOptions.vue:1202
	// Reference: src/components/ColOptions.vue:662
	// Reference: src/components/ContactFormOptions.vue:290
	// Reference: src/components/CountdownOptions.vue:845
	// Reference: src/components/CustomHTMLOptions.vue:197
	// Reference: src/components/DividerOptions.vue:358
	// Reference: src/components/FeatureOptions.vue:458
	// Reference: src/components/FormOptions.vue:176
	// Reference: src/components/GiveawayOptions.vue:162
	// Reference: src/components/GoogleMapsOptions.vue:227
	// Reference: src/components/HeaderOptions.vue:445
	// Reference: src/components/IconFeatureOptions.vue:448
	// Reference: src/components/IconOptions.vue:207
	// Reference: src/components/ImageOptions.vue:703
	// Reference: src/components/LoginOptions.vue:875
	// Reference: src/components/MenuCartOptions.vue:182
	// Reference: src/components/NavOptions.vue:568
	// Reference: src/components/OptinFormOptions.vue:841
	// Reference: src/components/PostauthorboxOptions.vue:334
	// Reference: src/components/PostcommentsOptions.vue:199
	// Reference: src/components/PostfeaturedimageOptions.vue:638
	// Reference: src/components/PostinfoOptions.vue:582
	// Reference: src/components/PostnavigationOptions.vue:93
	// Reference: src/components/PricingTableOptions.vue:1230
	// Reference: src/components/ProductDataTabsOptions.vue:335
	// Reference: src/components/ProductFeaturedImageOptions.vue:638
	// Reference: src/components/ProductMetaOptions.vue:328
	// Reference: src/components/ProductPriceOptions.vue:180
	// Reference: src/components/ProductRelatedOptions.vue:612
	// Reference: src/components/ProgressBarOptions.vue:319
	// Reference: src/components/RowOptions.vue:661
	// Reference: src/components/SectionOptions.vue:385
	// Reference: src/components/ShortcodeOptions.vue:141
	// Reference: src/components/SocialSharingOptions.vue:383
	// Reference: src/components/StarRatingOptions.vue:295
	// Reference: src/components/TemplatetagOptions.vue:121
	// Reference: src/components/TestimonialOptions.vue:542
	// Reference: src/components/TextOptions.vue:375
	// Reference: src/components/UpsellsOptions.vue:612
	// Reference: src/components/VideoOptions.vue:229
	// Reference: src/components/WCAddToCartOptions.vue:685
	// Reference: src/components/WCCustomProductsGridOptions.vue:1123
	// Reference: src/components/WpWidgetBlockOptions.vue:186
	__( 'Content', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue:600
	// Reference: src/components/AddToCartOptions.vue:1067
	// Reference: src/components/AdditionalInformationOptions.vue:128
	// Reference: src/components/BulletListOptions.vue:495
	// Reference: src/components/BusinessHoursOptions.vue:717
	// Reference: src/components/ButtonOptions.vue:1203
	// Reference: src/components/ColOptions.vue:679
	// Reference: src/components/ContactFormOptions.vue:291
	// Reference: src/components/CountdownOptions.vue:847
	// Reference: src/components/CustomHTMLOptions.vue:198
	// Reference: src/components/DividerOptions.vue:359
	// Reference: src/components/FeatureOptions.vue:459
	// Reference: src/components/FormOptions.vue:177
	// Reference: src/components/GiveawayOptions.vue:163
	// Reference: src/components/GoogleMapsOptions.vue:228
	// Reference: src/components/HeaderOptions.vue:446
	// Reference: src/components/IconFeatureOptions.vue:449
	// Reference: src/components/IconOptions.vue:208
	// Reference: src/components/ImageOptions.vue:705
	// Reference: src/components/LoginOptions.vue:876
	// Reference: src/components/MenuCartOptions.vue:183
	// Reference: src/components/NavOptions.vue:569
	// Reference: src/components/OptinFormOptions.vue:843
	// Reference: src/components/PostauthorboxOptions.vue:335
	// Reference: src/components/PostcommentsOptions.vue:200
	// Reference: src/components/PostfeaturedimageOptions.vue:640
	// Reference: src/components/PostinfoOptions.vue:583
	// Reference: src/components/PostnavigationOptions.vue:94
	// Reference: src/components/PostsOptions.vue:1455
	// Reference: src/components/PricingTableOptions.vue:1231
	// Reference: src/components/ProductDataTabsOptions.vue:336
	// Reference: src/components/ProductFeaturedImageOptions.vue:640
	// Reference: src/components/ProductMetaOptions.vue:329
	// Reference: src/components/ProductPriceOptions.vue:181
	// Reference: src/components/ProductRelatedOptions.vue:605
	// Reference: src/components/ProgressBarOptions.vue:321
	// Reference: src/components/RowOptions.vue:678
	// Reference: src/components/SectionOptions.vue:386
	// Reference: src/components/ShortcodeOptions.vue:142
	// Reference: src/components/SocialSharingOptions.vue:384
	// Reference: src/components/StarRatingOptions.vue:296
	// Reference: src/components/TemplatetagOptions.vue:122
	// Reference: src/components/TestimonialOptions.vue:543
	// Reference: src/components/TextOptions.vue:376
	// Reference: src/components/UpsellsOptions.vue:605
	// Reference: src/components/VideoOptions.vue:230
	// Reference: src/components/WCAddToCartOptions.vue:686
	// Reference: src/components/WCCartOptions.vue:495
	// Reference: src/components/WCCheckoutOptions.vue:763
	// Reference: src/components/WCCustomProductsGridOptions.vue:1076
	// Reference: src/components/WpWidgetBlockOptions.vue:187
	// Reference: src/views/SetupBlockOptions-Lite.vue:1169
	__( 'Advanced', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue:601
	__( 'Accordion', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue:602
	// Reference: src/components/BulletListOptions.vue:497
	// Reference: src/components/BusinessHoursOptions.vue:719
	// Reference: src/components/FormOptions.vue:179
	// Reference: src/components/NavOptions.vue:571
	// Reference: src/components/PricingTableOptions.vue:1233
	__( 'Add New Item', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue:603
	// Reference: src/components/BulletListOptions.vue:498
	// Reference: src/components/HeaderOptions.vue:451
	// Reference: src/components/NavOptions.vue:572
	// Reference: src/components/OptinFormOptions.vue:891
	// Reference: src/components/TextOptions.vue:380
	// Reference: src/components/TypographyControl.vue:278
	__( 'Font Size', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue:604
	// Reference: src/components/AddToCartOptions.vue:1070
	// Reference: src/components/BusinessHoursOptions.vue:722
	// Reference: src/components/ColOptions.vue:691
	// Reference: src/components/CountdownOptions.vue:875
	// Reference: src/components/NavOptions.vue:573
	// Reference: src/components/PostinfoOptions.vue:580
	// Reference: src/components/PricingTableOptions.vue:1292
	// Reference: src/components/ProductMetaOptions.vue:326
	// Reference: src/components/ProductPriceOptions.vue:185
	// Reference: src/components/RowOptions.vue:690
	// Reference: src/components/SocialProfilesOptions.vue:695
	// Reference: src/components/SocialSharingOptions.vue:404
	// Reference: src/components/SpaceBetweenControl.vue:84
	// Reference: src/components/StarRatingOptions.vue:303
	__( 'Space Between', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue:605
	// Reference: src/components/AddToCartOptions.vue:1071
	// Reference: src/components/BulletListOptions.vue:499
	// Reference: src/components/BusinessHoursOptions.vue:725
	// Reference: src/components/ButtonOptions.vue:1207
	// Reference: src/components/CountdownOptions.vue:885
	// Reference: src/components/DividerOptions.vue:361
	// Reference: src/components/GoogleMapsOptions.vue:229
	// Reference: src/components/HeaderOptions.vue:448
	// Reference: src/components/IconOptions.vue:209
	// Reference: src/components/ImageOptions.vue:708
	// Reference: src/components/MenuCartOptions.vue:185
	// Reference: src/components/PostauthorboxOptions.vue:354
	// Reference: src/components/PostfeaturedimageOptions.vue:643
	// Reference: src/components/PostsOptions.vue:1453
	// Reference: src/components/ProductFeaturedImageOptions.vue:643
	// Reference: src/components/ProductRelatedOptions.vue:603
	// Reference: src/components/ProgressBarOptions.vue:339
	// Reference: src/components/RowOptions.vue:664
	// Reference: src/components/SocialProfilesOptions.vue:702
	// Reference: src/components/SocialSharingOptions.vue:387
	// Reference: src/components/StarRatingOptions.vue:298
	// Reference: src/components/TextOptions.vue:378
	// Reference: src/components/UpsellsOptions.vue:603
	// Reference: src/components/VideoOptions.vue:232
	// Reference: src/components/WCAddToCartOptions.vue:690
	// Reference: src/components/WCCartOptions.vue:493
	// Reference: src/components/WCCheckoutOptions.vue:761
	// Reference: src/components/WCCustomProductsGridOptions.vue:1074
	// Reference: src/components/WpWidgetBlockOptions.vue:189
	__( 'Styles', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue:606
	// Reference: src/components/BulletListOptions.vue:500
	// Reference: src/components/BusinessHoursOptions.vue:726
	// Reference: src/components/NavOptions.vue:575
	__( 'List Layout', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue:607
	// Reference: src/components/BulletListOptions.vue:501
	// Reference: src/components/BusinessHoursOptions.vue:727
	// Reference: src/components/ColOptions.vue:681
	// Reference: src/components/NavOptions.vue:576
	// Reference: src/components/RowOptions.vue:680
	// Reference: src/components/ShadowControl.vue:140
	__( 'Vertical', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue:608
	// Reference: src/components/BulletListOptions.vue:502
	// Reference: src/components/BusinessHoursOptions.vue:728
	// Reference: src/components/ColOptions.vue:680
	// Reference: src/components/NavOptions.vue:577
	// Reference: src/components/RowOptions.vue:679
	// Reference: src/components/ShadowControl.vue:139
	__( 'Horizontal', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue:609
	// Reference: src/components/AdditionalInformationOptions.vue:126
	// Reference: src/components/BulletListOptions.vue:503
	// Reference: src/components/ContactFormOptions.vue:294
	// Reference: src/components/DividerOptions.vue:390
	// Reference: src/components/GiveawayOptions.vue:166
	// Reference: src/components/NavOptions.vue:578
	// Reference: src/components/PostinfoOptions.vue:606
	// Reference: src/components/ProductDataTabsOptions.vue:326
	// Reference: src/components/ProductMetaOptions.vue:341
	// Reference: src/components/StarRatingOptions.vue:305
	// Reference: src/components/WCCartOptions.vue:537
	// Reference: src/components/WCCheckoutOptions.vue:805
	// Reference: src/components/WCCustomProductsGridOptions.vue:1118
	// Reference: src/components/WpWidgetBlockOptions.vue:184
	__( 'Text Color', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue:610
	// Reference: src/components/BulletListOptions.vue:504
	// Reference: src/components/BusinessHoursOptions.vue:730
	// Reference: src/components/SpacingSectionControl.vue:74
	// Reference: src/components/WCCustomProductsGridOptions.vue:1125
	__( 'Spacing', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue:611
	// Reference: src/components/BulletListOptions.vue:505
	// Reference: src/components/BusinessHoursOptions.vue:731
	// Reference: src/components/SpacingSectionControl.vue:75
	__( 'Top Margin', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue:612
	// Reference: src/components/BulletListOptions.vue:506
	// Reference: src/components/DividerOptions.vue:381
	// Reference: src/components/FeatureOptions.vue:454
	// Reference: src/components/HeaderOptions.vue:450
	// Reference: src/components/IconFeatureOptions.vue:444
	// Reference: src/components/NavOptions.vue:579
	// Reference: src/components/PostsOptions.vue:1513
	// Reference: src/components/PricingTableOptions.vue:1244
	// Reference: src/components/TestimonialOptions.vue:544
	// Reference: src/components/TextOptions.vue:379
	// Reference: src/views/GlobalCSS.vue:1913
	// Reference: src/views/SetupDesign-Lite.vue:747
	__( 'Text', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue:613
	// Reference: src/components/BulletListOptions.vue:507
	// Reference: src/components/DividerOptions.vue:380
	// Reference: src/components/FeatureOptions.vue:449
	// Reference: src/components/IconFeatureOptions.vue:439
	// Reference: src/components/IconOptions.vue:210
	// Reference: src/components/PostinfoOptions.vue:597
	// Reference: src/components/PricingTableOptions.vue:1245
	// Reference: src/components/SocialProfilesOptions.vue:701
	// Reference: src/components/TestimonialOptions.vue:536
	__( 'Icon', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue:614
	// Reference: src/components/AddToCartOptions.vue:1081
	// Reference: src/components/BulletListOptions.vue:508
	// Reference: src/components/BusinessHoursOptions.vue:735
	// Reference: src/components/ButtonOptions.vue:1220
	// Reference: src/components/CountdownOptions.vue:871
	// Reference: src/components/ImageOptions.vue:716
	// Reference: src/components/OptinFormOptions.vue:867
	// Reference: src/components/PostfeaturedimageOptions.vue:651
	// Reference: src/components/ProductFeaturedImageOptions.vue:651
	// Reference: src/components/ProgressBarOptions.vue:325
	// Reference: src/components/SocialProfilesOptions.vue:670
	// Reference: src/components/WCAddToCartOptions.vue:703
	// Reference: src/components/WCCartOptions.vue:503
	// Reference: src/components/WCCheckoutOptions.vue:771
	// Reference: src/components/WCCustomProductsGridOptions.vue:1084
	__( 'Choose Your Style', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue:615
	__( 'Closed Icon Color', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue:616
	__( 'Closed Icon', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue:617
	__( 'Open Icon Color', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue:618
	__( 'Open Icon', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue:619
	// Reference: src/components/AdditionalInformationOptions.vue:125
	// Reference: src/components/FeatureOptions.vue:457
	// Reference: src/components/IconFeatureOptions.vue:447
	// Reference: src/components/WCCartOptions.vue:541
	// Reference: src/components/WCCheckoutOptions.vue:809
	// Reference: src/components/WCCustomProductsGridOptions.vue:1122
	// Reference: src/views/GlobalCSS.vue:1939
	__( 'Header Color', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue:620
	// Reference: src/components/PricingTableOptions.vue:1252
	__( 'Header Open Color', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue:621
	// Reference: src/components/BusinessHoursOptions.vue:749
	// Reference: src/components/PricingTableOptions.vue:1253
	// Reference: src/components/ProductMetaOptions.vue:344
	__( 'Divider Color', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue:622
	// Reference: src/components/AddToCartOptions.vue:1100
	// Reference: src/components/BackgroundControl.vue:462
	// Reference: src/components/BusinessHoursOptions.vue:739
	// Reference: src/components/ButtonOptions.vue:1239
	// Reference: src/components/ColOptions.vue:673
	// Reference: src/components/FeatureOptions.vue:455
	// Reference: src/components/HeaderOptions.vue:465
	// Reference: src/components/IconFeatureOptions.vue:445
	// Reference: src/components/OptinFormOptions.vue:878
	// Reference: src/components/PostauthorboxOptions.vue:358
	// Reference: src/components/PricingTableOptions.vue:1288
	// Reference: src/components/ProductDataTabsOptions.vue:327
	// Reference: src/components/ProgressBarOptions.vue:338
	// Reference: src/components/RowOptions.vue:675
	// Reference: src/components/SectionOptions.vue:383
	// Reference: src/components/SocialProfilesOptions.vue:715
	// Reference: src/components/TestimonialOptions.vue:539
	// Reference: src/components/TextOptions.vue:390
	// Reference: src/components/WCAddToCartOptions.vue:722
	// Reference: src/components/WCCartOptions.vue:536
	// Reference: src/components/WCCheckoutOptions.vue:804
	// Reference: src/components/WCCustomProductsGridOptions.vue:1117
	__( 'Background Color', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue:623
	// Reference: src/components/AddToCartOptions.vue:1098
	// Reference: src/components/BulletListOptions.vue:510
	// Reference: src/components/BusinessHoursOptions.vue:756
	// Reference: src/components/ButtonOptions.vue:1237
	// Reference: src/components/ColOptions.vue:665
	// Reference: src/components/HeaderOptions.vue:457
	// Reference: src/components/NavOptions.vue:599
	// Reference: src/components/PricingTableOptions.vue:1314
	// Reference: src/components/ProgressBarOptions.vue:328
	// Reference: src/components/TextOptions.vue:381
	// Reference: src/components/WCAddToCartOptions.vue:720
	__( 'Text Shadow', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue:631
	// Reference: src/components/BulletListOptions.vue:518
	// Reference: src/components/BusinessHoursOptions.vue:764
	// Reference: src/components/PaddingControl.vue:312
	// Reference: src/components/PricingTableOptions.vue:1322
	__( 'Padding', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue:632
	// Reference: src/components/BorderRadiusControl.vue:129
	// Reference: src/components/BorderWidthControl.vue:121
	// Reference: src/components/BulletListOptions.vue:519
	// Reference: src/components/BusinessHoursOptions.vue:765
	// Reference: src/components/DisplaySectionControl.vue:194
	// Reference: src/components/ImageOptions.vue:710
	// Reference: src/components/MarginControl.vue:333
	// Reference: src/components/PaddingControl.vue:313
	// Reference: src/components/PostfeaturedimageOptions.vue:645
	// Reference: src/components/PostsOptions.vue:1558
	// Reference: src/components/PricingTableOptions.vue:1323
	// Reference: src/components/ProductFeaturedImageOptions.vue:645
	// Reference: src/components/ProductRelatedOptions.vue:645
	// Reference: src/components/ShapeDividerControl.vue:347
	// Reference: src/components/UpsellsOptions.vue:645
	// Reference: src/components/WCCustomProductsGridOptions.vue:1183
	__( 'Top', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue:633
	// Reference: src/components/BorderRadiusControl.vue:132
	// Reference: src/components/BorderWidthControl.vue:123
	// Reference: src/components/BulletListOptions.vue:520
	// Reference: src/components/BusinessHoursOptions.vue:766
	// Reference: src/components/DisplaySectionControl.vue:196
	// Reference: src/components/ImageOptions.vue:712
	// Reference: src/components/MarginControl.vue:335
	// Reference: src/components/PaddingControl.vue:315
	// Reference: src/components/PostfeaturedimageOptions.vue:647
	// Reference: src/components/PostsOptions.vue:1559
	// Reference: src/components/PricingTableOptions.vue:1324
	// Reference: src/components/ProductFeaturedImageOptions.vue:647
	// Reference: src/components/ProductRelatedOptions.vue:647
	// Reference: src/components/ShapeDividerControl.vue:348
	// Reference: src/components/UpsellsOptions.vue:647
	// Reference: src/components/WCCustomProductsGridOptions.vue:1185
	__( 'Bottom', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue:634
	// Reference: src/components/BorderRadiusControl.vue:131
	// Reference: src/components/BorderWidthControl.vue:122
	// Reference: src/components/BulletListOptions.vue:521
	// Reference: src/components/BusinessHoursOptions.vue:767
	// Reference: src/components/DisplaySectionControl.vue:195
	// Reference: src/components/ImageOptions.vue:711
	// Reference: src/components/MarginControl.vue:334
	// Reference: src/components/PaddingControl.vue:314
	// Reference: src/components/PostfeaturedimageOptions.vue:646
	// Reference: src/components/PostsOptions.vue:1560
	// Reference: src/components/PricingTableOptions.vue:1325
	// Reference: src/components/ProductFeaturedImageOptions.vue:646
	// Reference: src/components/ProductRelatedOptions.vue:646
	// Reference: src/components/UpsellsOptions.vue:646
	// Reference: src/components/WCCustomProductsGridOptions.vue:1184
	__( 'Right', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue:635
	// Reference: src/components/BorderRadiusControl.vue:130
	// Reference: src/components/BorderWidthControl.vue:124
	// Reference: src/components/BulletListOptions.vue:522
	// Reference: src/components/BusinessHoursOptions.vue:768
	// Reference: src/components/DisplaySectionControl.vue:197
	// Reference: src/components/ImageOptions.vue:713
	// Reference: src/components/MarginControl.vue:336
	// Reference: src/components/PaddingControl.vue:316
	// Reference: src/components/PostfeaturedimageOptions.vue:648
	// Reference: src/components/PostsOptions.vue:1561
	// Reference: src/components/PricingTableOptions.vue:1326
	// Reference: src/components/ProductFeaturedImageOptions.vue:648
	// Reference: src/components/ProductRelatedOptions.vue:648
	// Reference: src/components/UpsellsOptions.vue:648
	// Reference: src/components/WCCustomProductsGridOptions.vue:1186
	__( 'Left', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue:636
	// Reference: src/components/AddToCartOptions.vue:1099
	// Reference: src/components/ButtonOptions.vue:1238
	// Reference: src/components/CountdownOptions.vue:877
	// Reference: src/components/DividerOptions.vue:370
	// Reference: src/components/GoogleMapsOptions.vue:231
	// Reference: src/components/IconOptions.vue:212
	// Reference: src/components/ImageOptions.vue:717
	// Reference: src/components/PostfeaturedimageOptions.vue:652
	// Reference: src/components/PostsOptions.vue:1530
	// Reference: src/components/PricingTableOptions.vue:1327
	// Reference: src/components/ProductFeaturedImageOptions.vue:652
	// Reference: src/components/ProductRelatedOptions.vue:630
	// Reference: src/components/ProgressBarOptions.vue:336
	// Reference: src/components/RowOptions.vue:667
	// Reference: src/components/SectionOptions.vue:370
	// Reference: src/components/ShadowControl.vue:129
	// Reference: src/components/SocialProfilesOptions.vue:696
	// Reference: src/components/SocialSharingOptions.vue:405
	// Reference: src/components/TextOptions.vue:389
	// Reference: src/components/UpsellsOptions.vue:630
	// Reference: src/components/VideoOptions.vue:239
	// Reference: src/components/WCAddToCartOptions.vue:721
	// Reference: src/components/WCCustomProductsGridOptions.vue:1168
	__( 'Shadow', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue:637
	// Reference: src/components/AddToCartOptions.vue:1107
	// Reference: src/components/BulletListOptions.vue:511
	// Reference: src/components/BusinessHoursOptions.vue:757
	// Reference: src/components/ButtonOptions.vue:1248
	// Reference: src/components/ColOptions.vue:666
	// Reference: src/components/CountdownOptions.vue:878
	// Reference: src/components/DividerOptions.vue:378
	// Reference: src/components/GoogleMapsOptions.vue:232
	// Reference: src/components/HeaderOptions.vue:458
	// Reference: src/components/IconOptions.vue:213
	// Reference: src/components/ImageOptions.vue:740
	// Reference: src/components/NavOptions.vue:600
	// Reference: src/components/PostauthorboxOptions.vue:351
	// Reference: src/components/PostfeaturedimageOptions.vue:653
	// Reference: src/components/PostinfoOptions.vue:598
	// Reference: src/components/PostsOptions.vue:1535
	// Reference: src/components/PricingTableOptions.vue:1328
	// Reference: src/components/ProductFeaturedImageOptions.vue:653
	// Reference: src/components/ProductRelatedOptions.vue:635
	// Reference: src/components/ProgressBarOptions.vue:329
	// Reference: src/components/RowOptions.vue:668
	// Reference: src/components/SectionOptions.vue:371
	// Reference: src/components/ShadowControl.vue:130
	// Reference: src/components/ShapeDividerControl.vue:350
	// Reference: src/components/SocialProfilesOptions.vue:697
	// Reference: src/components/SocialSharingOptions.vue:397
	// Reference: src/components/TextOptions.vue:382
	// Reference: src/components/UpsellsOptions.vue:635
	// Reference: src/components/VideoOptions.vue:240
	// Reference: src/components/WCAddToCartOptions.vue:723
	// Reference: src/components/WCCustomProductsGridOptions.vue:1173
	__( 'None', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue:638
	// Reference: src/components/AddToCartOptions.vue:1108
	// Reference: src/components/BulletListOptions.vue:512
	// Reference: src/components/BusinessHoursOptions.vue:758
	// Reference: src/components/ButtonOptions.vue:1249
	// Reference: src/components/ColOptions.vue:667
	// Reference: src/components/CountdownOptions.vue:879
	// Reference: src/components/DividerOptions.vue:372
	// Reference: src/components/GoogleMapsOptions.vue:233
	// Reference: src/components/HeaderOptions.vue:459
	// Reference: src/components/IconOptions.vue:214
	// Reference: src/components/ImageOptions.vue:719
	// Reference: src/components/NavOptions.vue:601
	// Reference: src/components/PostfeaturedimageOptions.vue:654
	// Reference: src/components/PostsOptions.vue:1536
	// Reference: src/components/PricingTableOptions.vue:1329
	// Reference: src/components/ProductFeaturedImageOptions.vue:654
	// Reference: src/components/ProductRelatedOptions.vue:636
	// Reference: src/components/ProgressBarOptions.vue:330
	// Reference: src/components/RowOptions.vue:669
	// Reference: src/components/SectionOptions.vue:372
	// Reference: src/components/ShadowControl.vue:131
	// Reference: src/components/SocialProfilesOptions.vue:698
	// Reference: src/components/SocialSharingOptions.vue:398
	// Reference: src/components/TextOptions.vue:383
	// Reference: src/components/UpsellsOptions.vue:636
	// Reference: src/components/VideoOptions.vue:241
	// Reference: src/components/WCAddToCartOptions.vue:724
	// Reference: src/components/WCCustomProductsGridOptions.vue:1174
	__( 'Hairline', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue:639
	// Reference: src/components/AddToCartOptions.vue:1109
	// Reference: src/components/BulletListOptions.vue:513
	// Reference: src/components/BusinessHoursOptions.vue:759
	// Reference: src/components/ButtonOptions.vue:1250
	// Reference: src/components/ColOptions.vue:668
	// Reference: src/components/CountdownOptions.vue:880
	// Reference: src/components/DividerOptions.vue:373
	// Reference: src/components/GoogleMapsOptions.vue:234
	// Reference: src/components/HeaderOptions.vue:460
	// Reference: src/components/IconOptions.vue:215
	// Reference: src/components/ImageOptions.vue:720
	// Reference: src/components/LoginOptions.vue:921
	// Reference: src/components/NavOptions.vue:602
	// Reference: src/components/OptinFormOptions.vue:855
	// Reference: src/components/PostfeaturedimageOptions.vue:655
	// Reference: src/components/PostsOptions.vue:1537
	// Reference: src/components/PricingTableOptions.vue:1330
	// Reference: src/components/ProductFeaturedImageOptions.vue:655
	// Reference: src/components/ProductRelatedOptions.vue:637
	// Reference: src/components/ProgressBarOptions.vue:331
	// Reference: src/components/RowOptions.vue:670
	// Reference: src/components/SectionOptions.vue:373
	// Reference: src/components/ShadowControl.vue:132
	// Reference: src/components/SocialProfilesOptions.vue:689
	// Reference: src/components/SocialSharingOptions.vue:399
	// Reference: src/components/TextOptions.vue:384
	// Reference: src/components/UpsellsOptions.vue:637
	// Reference: src/components/VideoOptions.vue:242
	// Reference: src/components/WCAddToCartOptions.vue:725
	// Reference: src/components/WCCustomProductsGridOptions.vue:1175
	__( 'Small', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue:640
	// Reference: src/components/AddToCartOptions.vue:1110
	// Reference: src/components/BulletListOptions.vue:514
	// Reference: src/components/BusinessHoursOptions.vue:760
	// Reference: src/components/ButtonOptions.vue:1251
	// Reference: src/components/ColOptions.vue:669
	// Reference: src/components/CountdownOptions.vue:881
	// Reference: src/components/DividerOptions.vue:374
	// Reference: src/components/GoogleMapsOptions.vue:235
	// Reference: src/components/HeaderOptions.vue:461
	// Reference: src/components/IconOptions.vue:216
	// Reference: src/components/ImageOptions.vue:721
	// Reference: src/components/LoginOptions.vue:922
	// Reference: src/components/NavOptions.vue:603
	// Reference: src/components/OptinFormOptions.vue:856
	// Reference: src/components/PostfeaturedimageOptions.vue:656
	// Reference: src/components/PostsOptions.vue:1538
	// Reference: src/components/PricingTableOptions.vue:1331
	// Reference: src/components/ProductFeaturedImageOptions.vue:656
	// Reference: src/components/ProductRelatedOptions.vue:638
	// Reference: src/components/ProgressBarOptions.vue:332
	// Reference: src/components/RowOptions.vue:671
	// Reference: src/components/SectionOptions.vue:374
	// Reference: src/components/ShadowControl.vue:133
	// Reference: src/components/SocialProfilesOptions.vue:704
	// Reference: src/components/SocialSharingOptions.vue:400
	// Reference: src/components/TextOptions.vue:385
	// Reference: src/components/UpsellsOptions.vue:638
	// Reference: src/components/VideoOptions.vue:243
	// Reference: src/components/WCAddToCartOptions.vue:726
	// Reference: src/components/WCCustomProductsGridOptions.vue:1176
	__( 'Medium', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue:641
	// Reference: src/components/AddToCartOptions.vue:1111
	// Reference: src/components/BulletListOptions.vue:515
	// Reference: src/components/BusinessHoursOptions.vue:761
	// Reference: src/components/ButtonOptions.vue:1252
	// Reference: src/components/ColOptions.vue:670
	// Reference: src/components/CountdownOptions.vue:882
	// Reference: src/components/DividerOptions.vue:375
	// Reference: src/components/GoogleMapsOptions.vue:236
	// Reference: src/components/HeaderOptions.vue:462
	// Reference: src/components/IconOptions.vue:217
	// Reference: src/components/ImageOptions.vue:722
	// Reference: src/components/LoginOptions.vue:923
	// Reference: src/components/NavOptions.vue:604
	// Reference: src/components/OptinFormOptions.vue:857
	// Reference: src/components/PostfeaturedimageOptions.vue:657
	// Reference: src/components/PostsOptions.vue:1539
	// Reference: src/components/PricingTableOptions.vue:1332
	// Reference: src/components/ProductFeaturedImageOptions.vue:657
	// Reference: src/components/ProductRelatedOptions.vue:639
	// Reference: src/components/ProgressBarOptions.vue:333
	// Reference: src/components/RowOptions.vue:672
	// Reference: src/components/SectionOptions.vue:375
	// Reference: src/components/ShadowControl.vue:134
	// Reference: src/components/SocialProfilesOptions.vue:691
	// Reference: src/components/SocialSharingOptions.vue:401
	// Reference: src/components/TextOptions.vue:386
	// Reference: src/components/UpsellsOptions.vue:639
	// Reference: src/components/VideoOptions.vue:244
	// Reference: src/components/WCAddToCartOptions.vue:727
	// Reference: src/components/WCCustomProductsGridOptions.vue:1177
	__( 'Large', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue:642
	// Reference: src/components/AddToCartOptions.vue:1112
	// Reference: src/components/BulletListOptions.vue:516
	// Reference: src/components/BusinessHoursOptions.vue:762
	// Reference: src/components/ButtonOptions.vue:1253
	// Reference: src/components/ColOptions.vue:671
	// Reference: src/components/CountdownOptions.vue:883
	// Reference: src/components/GoogleMapsOptions.vue:237
	// Reference: src/components/HeaderOptions.vue:463
	// Reference: src/components/IconOptions.vue:218
	// Reference: src/components/ImageOptions.vue:723
	// Reference: src/components/LoginOptions.vue:924
	// Reference: src/components/NavOptions.vue:605
	// Reference: src/components/OptinFormOptions.vue:858
	// Reference: src/components/PostfeaturedimageOptions.vue:658
	// Reference: src/components/PostsOptions.vue:1540
	// Reference: src/components/PricingTableOptions.vue:1333
	// Reference: src/components/ProductFeaturedImageOptions.vue:658
	// Reference: src/components/ProductRelatedOptions.vue:640
	// Reference: src/components/ProgressBarOptions.vue:334
	// Reference: src/components/RowOptions.vue:673
	// Reference: src/components/SectionOptions.vue:376
	// Reference: src/components/ShadowControl.vue:135
	// Reference: src/components/SocialProfilesOptions.vue:699
	// Reference: src/components/SocialSharingOptions.vue:402
	// Reference: src/components/TextOptions.vue:387
	// Reference: src/components/UpsellsOptions.vue:640
	// Reference: src/components/VideoOptions.vue:245
	// Reference: src/components/WCAddToCartOptions.vue:728
	// Reference: src/components/WCCustomProductsGridOptions.vue:1178
	__( 'X Large', 'coming-soon' ),

	// Reference: src/components/AccordionOptions.vue:643
	// Reference: src/components/AddToCartOptions.vue:1113
	// Reference: src/components/BulletListOptions.vue:517
	// Reference: src/components/BusinessHoursOptions.vue:763
	// Reference: src/components/ButtonOptions.vue:1254
	// Reference: src/components/ColOptions.vue:672
	// Reference: src/components/CountdownOptions.vue:884
	// Reference: src/components/GoogleMapsOptions.vue:238
	// Reference: src/components/HeaderOptions.vue:464
	// Reference: src/components/IconOptions.vue:219
	// Reference: src/components/ImageOptions.vue:724
	// Reference: src/components/LoginOptions.vue:925
	// Reference: src/components/NavOptions.vue:606
	// Reference: src/components/OptinFormOptions.vue:859
	// Reference: src/components/PostfeaturedimageOptions.vue:659
	// Reference: src/components/PostsOptions.vue:1541
	// Reference: src/components/PricingTableOptions.vue:1334
	// Reference: src/components/ProductFeaturedImageOptions.vue:659
	// Reference: src/components/ProductRelatedOptions.vue:641
	// Reference: src/components/ProgressBarOptions.vue:335
	// Reference: src/components/RowOptions.vue:674
	// Reference: src/components/SectionOptions.vue:377
	// Reference: src/components/ShadowControl.vue:136
	// Reference: src/components/SocialSharingOptions.vue:403
	// Reference: src/components/TextOptions.vue:388
	// Reference: src/components/UpsellsOptions.vue:641
	// Reference: src/components/VideoOptions.vue:246
	// Reference: src/components/WCAddToCartOptions.vue:729
	// Reference: src/components/WCCustomProductsGridOptions.vue:1179
	__( '2X Large', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1068
	// Reference: src/components/ButtonOptions.vue:1204
	// Reference: src/components/LoginOptions.vue:901
	// Reference: src/components/OptinFormOptions.vue:849
	// Reference: src/components/ProductRelatedOptions.vue:620
	// Reference: src/components/UpsellsOptions.vue:620
	// Reference: src/components/WCAddToCartOptions.vue:687
	// Reference: src/components/WCCustomProductsGridOptions.vue:1158
	// Reference: src/views/GlobalCSS.vue:1983
	__( 'Button', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1069
	// Reference: src/components/ButtonOptions.vue:1205
	// Reference: src/components/LoginOptions.vue:886
	// Reference: src/components/WCAddToCartOptions.vue:688
	__( 'Button Text', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1072
	// Reference: src/components/BackgroundControl.vue:481
	// Reference: src/components/ButtonOptions.vue:1211
	// Reference: src/components/CountdownOptions.vue:856
	// Reference: src/components/FeatureOptions.vue:451
	// Reference: src/components/IconFeatureOptions.vue:441
	// Reference: src/components/IconOptions.vue:211
	// Reference: src/components/OptinFormOptions.vue:853
	// Reference: src/components/PostinfoOptions.vue:578
	// Reference: src/components/SocialProfilesOptions.vue:688
	// Reference: src/components/SocialSharingOptions.vue:396
	// Reference: src/components/StarRatingOptions.vue:302
	// Reference: src/components/TestimonialOptions.vue:538
	// Reference: src/components/WCAddToCartOptions.vue:694
	__( 'Size', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1073
	// Reference: src/components/ButtonOptions.vue:1212
	// Reference: src/components/WCAddToCartOptions.vue:695
	__( 'Vertical Padding', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1074
	// Reference: src/components/ButtonOptions.vue:1213
	// Reference: src/components/WCAddToCartOptions.vue:696
	__( 'Horizontal Padding', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1075
	// Reference: src/components/BorderRadiusControl.vue:128
	// Reference: src/components/BorderSectionControl.vue:81
	// Reference: src/components/ButtonOptions.vue:1214
	// Reference: src/components/CountdownOptions.vue:876
	// Reference: src/components/ImageOptions.vue:726
	// Reference: src/components/OptinFormOptions.vue:869
	// Reference: src/components/PostfeaturedimageOptions.vue:661
	// Reference: src/components/PostsOptions.vue:1512
	// Reference: src/components/PricingTableOptions.vue:1254
	// Reference: src/components/ProductDataTabsOptions.vue:330
	// Reference: src/components/ProductFeaturedImageOptions.vue:661
	// Reference: src/components/ProductRelatedOptions.vue:606
	// Reference: src/components/ProgressBarOptions.vue:327
	// Reference: src/components/SectionOptions.vue:378
	// Reference: src/components/SocialProfilesOptions.vue:693
	// Reference: src/components/UpsellsOptions.vue:606
	// Reference: src/components/WCAddToCartOptions.vue:697
	// Reference: src/components/WCCartOptions.vue:535
	// Reference: src/components/WCCheckoutOptions.vue:803
	// Reference: src/components/WCCustomProductsGridOptions.vue:1116
	__( 'Border Radius', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1076
	// Reference: src/components/ButtonOptions.vue:1215
	// Reference: src/components/HeaderOptions.vue:449
	// Reference: src/components/WCAddToCartOptions.vue:698
	__( 'Icons', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1077
	// Reference: src/components/ButtonOptions.vue:1216
	// Reference: src/components/HeaderOptions.vue:466
	// Reference: src/components/OptinFormOptions.vue:876
	// Reference: src/components/WCAddToCartOptions.vue:699
	__( 'Before Text Icon', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1078
	// Reference: src/components/ButtonOptions.vue:1217
	// Reference: src/components/HeaderOptions.vue:467
	// Reference: src/components/OptinFormOptions.vue:877
	// Reference: src/components/WCAddToCartOptions.vue:700
	__( 'After Text Icon', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1079
	// Reference: src/components/BusinessHoursOptions.vue:713
	// Reference: src/components/ButtonOptions.vue:1218
	// Reference: src/components/CountdownOptions.vue:846
	// Reference: src/components/ImageOptions.vue:704
	// Reference: src/components/LoginOptions.vue:927
	// Reference: src/components/OptinFormOptions.vue:842
	// Reference: src/components/PostfeaturedimageOptions.vue:639
	// Reference: src/components/ProductFeaturedImageOptions.vue:639
	// Reference: src/components/ProgressBarOptions.vue:320
	// Reference: src/components/WCAddToCartOptions.vue:701
	// Reference: src/components/WCCartOptions.vue:494
	// Reference: src/components/WCCheckoutOptions.vue:762
	__( 'Templates', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1080
	// Reference: src/components/ButtonOptions.vue:1219
	// Reference: src/components/CountdownOptions.vue:857
	// Reference: src/components/OptinFormOptions.vue:854
	// Reference: src/components/WCAddToCartOptions.vue:702
	__( 'Tiny', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1082
	// Reference: src/components/ButtonOptions.vue:1221
	// Reference: src/components/WCAddToCartOptions.vue:704
	__( 'Pill Button', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1083
	// Reference: src/components/ButtonOptions.vue:1222
	// Reference: src/components/WCAddToCartOptions.vue:705
	__( 'Flat Button', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1084
	// Reference: src/components/ButtonOptions.vue:1223
	// Reference: src/components/WCAddToCartOptions.vue:706
	__( 'Blue Button', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1085
	// Reference: src/components/ButtonOptions.vue:1224
	// Reference: src/components/WCAddToCartOptions.vue:707
	__( 'Light Green Button', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1086
	// Reference: src/components/ButtonOptions.vue:1225
	// Reference: src/components/WCAddToCartOptions.vue:708
	__( 'Green Button', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1087
	// Reference: src/components/ButtonOptions.vue:1226
	// Reference: src/components/WCAddToCartOptions.vue:709
	__( 'Orange Button', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1088
	// Reference: src/components/ButtonOptions.vue:1227
	// Reference: src/components/WCAddToCartOptions.vue:710
	__( 'Red Button', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1089
	// Reference: src/components/ButtonOptions.vue:1228
	// Reference: src/components/WCAddToCartOptions.vue:711
	__( 'Yellow Button', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1090
	// Reference: src/components/ButtonOptions.vue:1229
	// Reference: src/components/WCAddToCartOptions.vue:712
	__( 'White Button', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1091
	// Reference: src/components/ButtonOptions.vue:1230
	// Reference: src/components/WCAddToCartOptions.vue:713
	__( 'Grey Button', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1092
	// Reference: src/components/ButtonOptions.vue:1231
	// Reference: src/components/WCAddToCartOptions.vue:714
	__( 'Black Button', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1093
	// Reference: src/components/ButtonOptions.vue:1232
	// Reference: src/components/OptinFormOptions.vue:871
	// Reference: src/components/ProductRelatedOptions.vue:621
	// Reference: src/components/UpsellsOptions.vue:621
	// Reference: src/components/WCAddToCartOptions.vue:715
	// Reference: src/components/WCCartOptions.vue:522
	// Reference: src/components/WCCheckoutOptions.vue:790
	// Reference: src/components/WCCustomProductsGridOptions.vue:1159
	__( 'Button Style', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1094
	// Reference: src/components/ButtonOptions.vue:1233
	// Reference: src/components/OptinFormOptions.vue:872
	// Reference: src/components/ProductRelatedOptions.vue:607
	// Reference: src/components/UpsellsOptions.vue:607
	// Reference: src/components/WCAddToCartOptions.vue:716
	// Reference: src/components/WCCartOptions.vue:525
	// Reference: src/components/WCCheckoutOptions.vue:793
	// Reference: src/components/WCCustomProductsGridOptions.vue:1106
	__( 'Flat', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1095
	// Reference: src/components/ButtonOptions.vue:1234
	// Reference: src/components/OptinFormOptions.vue:874
	// Reference: src/components/ProductRelatedOptions.vue:608
	// Reference: src/components/UpsellsOptions.vue:608
	// Reference: src/components/WCAddToCartOptions.vue:717
	// Reference: src/components/WCCartOptions.vue:526
	// Reference: src/components/WCCheckoutOptions.vue:794
	// Reference: src/components/WCCustomProductsGridOptions.vue:1107
	__( '2D', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1096
	// Reference: src/components/ButtonOptions.vue:1235
	// Reference: src/components/OptinFormOptions.vue:875
	// Reference: src/components/ProductRelatedOptions.vue:609
	// Reference: src/components/UpsellsOptions.vue:609
	// Reference: src/components/WCAddToCartOptions.vue:718
	// Reference: src/components/WCCartOptions.vue:527
	// Reference: src/components/WCCheckoutOptions.vue:795
	// Reference: src/components/WCCustomProductsGridOptions.vue:1108
	__( 'Vintage', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1097
	// Reference: src/components/ButtonOptions.vue:1236
	// Reference: src/components/OptinFormOptions.vue:873
	// Reference: src/components/ProductRelatedOptions.vue:610
	// Reference: src/components/UpsellsOptions.vue:610
	// Reference: src/components/WCAddToCartOptions.vue:719
	// Reference: src/components/WCCartOptions.vue:528
	// Reference: src/components/WCCheckoutOptions.vue:796
	// Reference: src/components/WCCustomProductsGridOptions.vue:1109
	__( 'Ghost', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1101
	// Reference: src/components/ButtonOptions.vue:1240
	// Reference: src/components/LoginOptions.vue:893
	// Reference: src/views/GlobalCSS.vue:1985
	__( 'Button Text Color', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1102
	// Reference: src/components/ButtonOptions.vue:1241
	// Reference: src/views/GlobalCSS.vue:1990
	__( 'Button Background Style', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1103
	// Reference: src/components/BackgroundControl.vue:435
	// Reference: src/components/BorderSectionControl.vue:83
	// Reference: src/components/BusinessHoursOptions.vue:746
	// Reference: src/components/ButtonOptions.vue:1242
	// Reference: src/components/ImageOptions.vue:728
	// Reference: src/components/PostfeaturedimageOptions.vue:663
	// Reference: src/components/PostsOptions.vue:1532
	// Reference: src/components/PricingTableOptions.vue:1308
	// Reference: src/components/ProductFeaturedImageOptions.vue:663
	// Reference: src/components/ProductRelatedOptions.vue:632
	// Reference: src/components/SectionOptions.vue:380
	// Reference: src/components/UpsellsOptions.vue:632
	// Reference: src/components/WCCustomProductsGridOptions.vue:1170
	// Reference: src/views/GlobalCSS.vue:1988
	__( 'Solid', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1104
	// Reference: src/components/BackgroundControl.vue:436
	// Reference: src/components/ButtonOptions.vue:1243
	// Reference: src/views/GlobalCSS.vue:1991
	__( 'Gradient', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1105
	// Reference: src/components/ButtonOptions.vue:1246
	// Reference: src/components/ProductDataTabsOptions.vue:324
	// Reference: src/components/TypographyControl.vue:284
	// Reference: src/views/GlobalCSS.vue:1956
	__( 'Normal', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1106
	// Reference: src/components/ButtonOptions.vue:1247
	// Reference: src/views/GlobalCSS.vue:1957
	__( 'Hover', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1114
	// Reference: src/components/ButtonOptions.vue:1255
	// Reference: src/components/ImageOptions.vue:734
	// Reference: src/components/PostauthorboxOptions.vue:350
	// Reference: src/components/PostfeaturedimageOptions.vue:669
	// Reference: src/components/PostinfoOptions.vue:579
	// Reference: src/components/ProductFeaturedImageOptions.vue:669
	// Reference: src/components/ProductRelatedOptions.vue:611
	// Reference: src/components/UpsellsOptions.vue:611
	// Reference: src/components/WCAddToCartOptions.vue:730
	// Reference: src/components/WCCartOptions.vue:529
	// Reference: src/components/WCCheckoutOptions.vue:797
	// Reference: src/components/WCCustomProductsGridOptions.vue:1110
	// Reference: src/views/GlobalCSS.vue:1955
	// Reference: src/views/SettingsGeneral.vue:224
	__( 'Link', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1115
	// Reference: src/components/BackgroundControl.vue:437
	// Reference: src/components/ButtonOptions.vue:1256
	// Reference: src/views/GlobalCSS.vue:1992
	__( 'Gradient Type', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1116
	// Reference: src/components/BackgroundControl.vue:438
	// Reference: src/components/ButtonOptions.vue:1257
	// Reference: src/views/GlobalCSS.vue:1993
	__( 'Radial', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1117
	// Reference: src/components/BackgroundControl.vue:439
	// Reference: src/components/ButtonOptions.vue:1258
	// Reference: src/views/GlobalCSS.vue:1994
	__( 'Linear', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1118
	// Reference: src/components/BackgroundControl.vue:440
	// Reference: src/components/ButtonOptions.vue:1259
	// Reference: src/views/GlobalCSS.vue:1995
	__( 'Angle', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1119
	// Reference: src/components/BackgroundControl.vue:470
	// Reference: src/components/ButtonOptions.vue:1260
	// Reference: src/components/DisplaySectionControl.vue:188
	// Reference: src/components/ShadowControl.vue:143
	// Reference: src/views/GlobalCSS.vue:1996
	__( 'Position', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1120
	// Reference: src/components/BackgroundControl.vue:442
	// Reference: src/components/ButtonOptions.vue:1261
	// Reference: src/views/GlobalCSS.vue:1997
	__( 'Top Center', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1121
	// Reference: src/components/BackgroundControl.vue:443
	// Reference: src/components/ButtonOptions.vue:1262
	// Reference: src/components/PostsOptions.vue:1551
	// Reference: src/views/GlobalCSS.vue:1998
	__( 'Top Left', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1122
	// Reference: src/components/BackgroundControl.vue:444
	// Reference: src/components/ButtonOptions.vue:1263
	// Reference: src/components/PostsOptions.vue:1550
	// Reference: src/views/GlobalCSS.vue:1999
	__( 'Top Right', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1123
	// Reference: src/components/BackgroundControl.vue:445
	// Reference: src/components/ButtonOptions.vue:1264
	// Reference: src/views/GlobalCSS.vue:2000
	__( 'Center Center', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1124
	// Reference: src/components/BackgroundControl.vue:446
	// Reference: src/components/ButtonOptions.vue:1265
	// Reference: src/views/GlobalCSS.vue:2001
	__( 'Center Left', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1125
	// Reference: src/components/BackgroundControl.vue:447
	// Reference: src/components/ButtonOptions.vue:1266
	// Reference: src/views/GlobalCSS.vue:2002
	__( 'Center Right', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1126
	// Reference: src/components/BackgroundControl.vue:448
	// Reference: src/components/ButtonOptions.vue:1267
	// Reference: src/views/GlobalCSS.vue:2003
	__( 'Bottom Center', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1127
	// Reference: src/components/BackgroundControl.vue:449
	// Reference: src/components/ButtonOptions.vue:1268
	// Reference: src/components/PostsOptions.vue:1553
	// Reference: src/views/GlobalCSS.vue:2004
	__( 'Bottom Left', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1128
	// Reference: src/components/BackgroundControl.vue:450
	// Reference: src/components/ButtonOptions.vue:1269
	// Reference: src/components/PostsOptions.vue:1552
	// Reference: src/views/GlobalCSS.vue:2005
	__( 'Bottom Right', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1129
	// Reference: src/components/BackgroundControl.vue:451
	// Reference: src/components/ButtonOptions.vue:1270
	// Reference: src/views/GlobalCSS.vue:2006
	__( 'First Color Location', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1130
	// Reference: src/components/BackgroundControl.vue:452
	// Reference: src/components/ButtonOptions.vue:1271
	// Reference: src/views/GlobalCSS.vue:2007
	__( 'Second Color Location', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1131
	// Reference: src/components/BackgroundControl.vue:460
	// Reference: src/components/ButtonOptions.vue:1272
	// Reference: src/views/GlobalCSS.vue:2008
	__( 'First Color', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1132
	// Reference: src/components/BackgroundControl.vue:461
	// Reference: src/components/ButtonOptions.vue:1273
	// Reference: src/views/GlobalCSS.vue:2009
	__( 'Second Color', 'coming-soon' ),

	// Reference: src/components/AddToCartOptions.vue:1133
	// Reference: src/components/BackgroundControl.vue:485
	// Reference: src/components/ButtonOptions.vue:1274
	// Reference: src/components/PostinfoOptions.vue:594
	// Reference: src/components/PostsOptions.vue:1459
	// Reference: src/components/PricingTableOptions.vue:1272
	// Reference: src/components/ProductMetaOptions.vue:335
	// Reference: src/components/ShadowControl.vue:137
	// Reference: src/components/SocialProfilesOptions.vue:713
	// Reference: src/components/VideoOptions.vue:235
	__( 'Custom', 'coming-soon' ),

	// Reference: src/components/AdditionalInformationOptions.vue:124
	// Reference: src/components/PricingTableOptions.vue:1237
	__( 'Header', 'coming-soon' ),

	// Reference: src/components/AlignControl.vue:344
	__( 'Align', 'coming-soon' ),

	// Reference: src/components/AnchorOptions.vue:76
	__( 'Anchor', 'coming-soon' ),

	// Reference: src/components/AttributeSectionControl.vue:81
	__( 'Attributes', 'coming-soon' ),

	// Reference: src/components/AttributeSectionControl.vue:82
	__( 'Custom Class', 'coming-soon' ),

	// Reference: src/components/AttributeSectionControl.vue:83
	__( 'Css ID', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue:434
	__( 'Background Style', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue:453
	__( 'Background Position', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue:454
	__( 'Full Screen Cover - Fixed', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue:455
	__( '100% Width Top', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue:457
	__( 'Repeat Horizontal Top', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue:458
	__( 'Repeat Horizontal Bottom', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue:459
	__( 'Repeat Vertical Center', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue:463
	__( '100% Width Bottom', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue:465
	__( 'Custom Position', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue:466
	__( 'Background Image', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue:467
	__( 'Full Screen Contain - Fixed', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue:468
	__( 'Full Screen Cover', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue:469
	__( 'Full Screen Contain', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue:471
	__( 'X Position', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue:472
	__( 'Y Position', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue:473
	__( 'Attachment', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue:474
	// Reference: src/components/ColOptions.vue:696
	// Reference: src/components/FontControl.vue:25
	// Reference: src/components/ImageOptions.vue:742
	// Reference: src/components/PostinfoOptions.vue:593
	// Reference: src/components/PostsOptions.vue:1458
	// Reference: src/components/ProductMetaOptions.vue:334
	// Reference: src/components/RowOptions.vue:695
	// Reference: src/components/SocialProfilesOptions.vue:686
	// Reference: src/components/WCCartOptions.vue:542
	// Reference: src/components/WCCheckoutOptions.vue:811
	__( 'Default', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue:475
	// Reference: src/components/DisplaySectionControl.vue:202
	__( 'Scroll', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue:476
	// Reference: src/components/DisplaySectionControl.vue:191
	__( 'Fixed', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue:477
	__( 'Repeat', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue:478
	__( 'No-repeat', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue:479
	__( 'Repeat-x', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue:480
	__( 'Repeat-y', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue:482
	// Reference: src/components/DisplaySectionControl.vue:203
	__( 'Auto', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue:483
	// Reference: src/components/ImageOptions.vue:744
	__( 'Cover', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue:484
	// Reference: src/components/ImageOptions.vue:745
	__( 'Contain', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue:486
	// Reference: src/components/DividerOptions.vue:367
	// Reference: src/components/GoogleMapsOptions.vue:230
	// Reference: src/components/ImageOptions.vue:707
	// Reference: src/components/OptinFormOptions.vue:851
	// Reference: src/components/PostfeaturedimageOptions.vue:642
	// Reference: src/components/ProductFeaturedImageOptions.vue:642
	// Reference: src/components/RowOptions.vue:665
	// Reference: src/components/ShapeDividerControl.vue:370
	// Reference: src/components/VideoOptions.vue:238
	__( 'Width', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue:487
	// Reference: src/components/ColOptions.vue:698
	// Reference: src/components/RowOptions.vue:701
	// Reference: src/components/SectionOptions.vue:391
	// Reference: src/views/GlobalCSS.vue:1897
	// Reference: src/views/SetupDesign-Lite.vue:734
	__( 'Dim Background', 'coming-soon' ),

	// Reference: src/components/BackgroundControl.vue:488
	// Reference: src/components/ColOptions.vue:699
	// Reference: src/components/RowOptions.vue:702
	// Reference: src/components/SectionOptions.vue:392
	__( 'Overlay Color', 'coming-soon' ),

	// Reference: src/components/BorderSectionControl.vue:80
	// Reference: src/components/PostsOptions.vue:1511
	// Reference: src/components/SectionOptions.vue:389
	__( 'Border', 'coming-soon' ),

	// Reference: src/components/BorderSectionControl.vue:82
	// Reference: src/components/ImageOptions.vue:727
	// Reference: src/components/PostfeaturedimageOptions.vue:662
	// Reference: src/components/PostsOptions.vue:1531
	// Reference: src/components/PricingTableOptions.vue:1307
	// Reference: src/components/ProductFeaturedImageOptions.vue:662
	// Reference: src/components/ProductRelatedOptions.vue:631
	// Reference: src/components/SectionOptions.vue:379
	// Reference: src/components/UpsellsOptions.vue:631
	// Reference: src/components/WCCustomProductsGridOptions.vue:1169
	__( 'Border Style', 'coming-soon' ),

	// Reference: src/components/BorderSectionControl.vue:84
	// Reference: src/components/BusinessHoursOptions.vue:747
	// Reference: src/components/DividerOptions.vue:364
	// Reference: src/components/ImageOptions.vue:729
	// Reference: src/components/PostfeaturedimageOptions.vue:664
	// Reference: src/components/PostsOptions.vue:1533
	// Reference: src/components/PricingTableOptions.vue:1309
	// Reference: src/components/ProductFeaturedImageOptions.vue:664
	// Reference: src/components/ProductRelatedOptions.vue:633
	// Reference: src/components/SectionOptions.vue:381
	// Reference: src/components/UpsellsOptions.vue:633
	// Reference: src/components/WCCustomProductsGridOptions.vue:1171
	// Reference: src/views/GlobalCSS.vue:1970
	__( 'Dotted', 'coming-soon' ),

	// Reference: src/components/BorderSectionControl.vue:85
	// Reference: src/components/BusinessHoursOptions.vue:748
	// Reference: src/components/DividerOptions.vue:365
	// Reference: src/components/ImageOptions.vue:730
	// Reference: src/components/PostfeaturedimageOptions.vue:665
	// Reference: src/components/PostsOptions.vue:1534
	// Reference: src/components/PricingTableOptions.vue:1310
	// Reference: src/components/ProductFeaturedImageOptions.vue:665
	// Reference: src/components/ProductRelatedOptions.vue:634
	// Reference: src/components/SectionOptions.vue:382
	// Reference: src/components/UpsellsOptions.vue:634
	// Reference: src/components/WCCustomProductsGridOptions.vue:1172
	// Reference: src/views/GlobalCSS.vue:1971
	__( 'Dashed', 'coming-soon' ),

	// Reference: src/components/BorderSectionControl.vue:86
	// Reference: src/components/ImageOptions.vue:733
	// Reference: src/components/PostfeaturedimageOptions.vue:668
	// Reference: src/components/PostsOptions.vue:1527
	// Reference: src/components/PricingTableOptions.vue:1311
	// Reference: src/components/ProductDataTabsOptions.vue:328
	// Reference: src/components/ProductFeaturedImageOptions.vue:668
	// Reference: src/components/SectionOptions.vue:384
	__( 'Border Color', 'coming-soon' ),

	// Reference: src/components/BorderWidthControl.vue:120
	// Reference: src/components/ImageOptions.vue:731
	// Reference: src/components/PostfeaturedimageOptions.vue:666
	// Reference: src/components/PostsOptions.vue:1528
	// Reference: src/components/PricingTableOptions.vue:1312
	// Reference: src/components/ProductDataTabsOptions.vue:337
	// Reference: src/components/ProductFeaturedImageOptions.vue:666
	__( 'Border Width', 'coming-soon' ),

	// Reference: src/components/BulletListOptions.vue:496
	__( 'List', 'coming-soon' ),

	// Reference: src/components/BulletListOptions.vue:509
	// Reference: src/components/BusinessHoursOptions.vue:736
	// Reference: src/components/DividerOptions.vue:391
	// Reference: src/components/PostinfoOptions.vue:607
	// Reference: src/components/PricingTableOptions.vue:1291
	// Reference: src/components/SocialProfilesOptions.vue:700
	__( 'Icon Color', 'coming-soon' ),

	// Reference: src/components/BusinessHoursOptions.vue:714
	__( 'Striped Effect Template', 'coming-soon' ),

	// Reference: src/components/BusinessHoursOptions.vue:715
	__( 'Divider Template', 'coming-soon' ),

	// Reference: src/components/BusinessHoursOptions.vue:716
	__( 'Background Template', 'coming-soon' ),

	// Reference: src/components/BusinessHoursOptions.vue:718
	__( 'Business Days and Timing', 'coming-soon' ),

	// Reference: src/components/BusinessHoursOptions.vue:720
	__( 'Date Font Size', 'coming-soon' ),

	// Reference: src/components/BusinessHoursOptions.vue:721
	__( 'Time Font Size', 'coming-soon' ),

	// Reference: src/components/BusinessHoursOptions.vue:723
	__( 'Date Align', 'coming-soon' ),

	// Reference: src/components/BusinessHoursOptions.vue:724
	__( 'Time Align', 'coming-soon' ),

	// Reference: src/components/BusinessHoursOptions.vue:732
	__( 'Enter Day', 'coming-soon' ),

	// Reference: src/components/BusinessHoursOptions.vue:733
	__( 'Enter Time', 'coming-soon' ),

	// Reference: src/components/BusinessHoursOptions.vue:734
	__( 'Style Day/Time', 'coming-soon' ),

	// Reference: src/components/BusinessHoursOptions.vue:738
	// Reference: src/components/PostinfoOptions.vue:573
	__( 'Time', 'coming-soon' ),

	// Reference: src/components/BusinessHoursOptions.vue:740
	__( 'Day Color', 'coming-soon' ),

	// Reference: src/components/BusinessHoursOptions.vue:741
	__( 'Time Color', 'coming-soon' ),

	// Reference: src/components/BusinessHoursOptions.vue:744
	// Reference: src/components/DividerOptions.vue:360
	// Reference: src/components/NavOptions.vue:587
	// Reference: src/components/PostinfoOptions.vue:605
	// Reference: src/components/ProductMetaOptions.vue:340
	__( 'Divider', 'coming-soon' ),

	// Reference: src/components/BusinessHoursOptions.vue:745
	// Reference: src/components/DividerOptions.vue:362
	// Reference: src/components/SocialProfilesOptions.vue:685
	// Reference: src/components/TypographyControl.vue:281
	__( 'Style', 'coming-soon' ),

	// Reference: src/components/BusinessHoursOptions.vue:750
	__( 'Weight', 'coming-soon' ),

	// Reference: src/components/BusinessHoursOptions.vue:751
	__( 'Day and Time', 'coming-soon' ),

	// Reference: src/components/BusinessHoursOptions.vue:752
	__( 'Striped Effect', 'coming-soon' ),

	// Reference: src/components/BusinessHoursOptions.vue:753
	__( 'Striped Odd Rows Color', 'coming-soon' ),

	// Reference: src/components/BusinessHoursOptions.vue:754
	__( 'Striped Even Rows Color', 'coming-soon' ),

	// Reference: src/components/BusinessHoursOptions.vue:755
	// Reference: src/components/ColOptions.vue:674
	// Reference: src/components/PostauthorboxOptions.vue:357
	// Reference: src/components/PostcommentsOptions.vue:202
	// Reference: src/components/PostinfoOptions.vue:608
	// Reference: src/components/ProductMetaOptions.vue:343
	// Reference: src/components/RowOptions.vue:663
	// Reference: src/components/SectionOptions.vue:387
	// Reference: src/views/GlobalCSS.vue:1922
	// Reference: src/views/SetupDesign-Lite.vue:756
	__( 'Background', 'coming-soon' ),

	// Reference: src/components/ButtonOptions.vue:1206
	// Reference: src/components/NavOptions.vue:582
	// Reference: src/components/PricingTableOptions.vue:1283
	// Reference: src/components/WCAddToCartOptions.vue:689
	__( 'Add "No Follow"', 'coming-soon' ),

	// Reference: src/components/ButtonOptions.vue:1208
	// Reference: src/components/OptinFormOptions.vue:860
	// Reference: src/components/WCAddToCartOptions.vue:691
	__( 'Button Sub Text', 'coming-soon' ),

	// Reference: src/components/ButtonOptions.vue:1210
	// Reference: src/components/ImageOptions.vue:735
	// Reference: src/components/NavOptions.vue:581
	// Reference: src/components/PostfeaturedimageOptions.vue:670
	// Reference: src/components/PricingTableOptions.vue:1282
	// Reference: src/components/ProductFeaturedImageOptions.vue:670
	// Reference: src/components/WCAddToCartOptions.vue:693
	__( 'Open In New Window', 'coming-soon' ),

	// Reference: src/components/ButtonOptions.vue:1244
	__( 'Button Border Width', 'coming-soon' ),

	// Reference: src/components/ButtonOptions.vue:1245
	// Reference: src/views/GlobalCSS.vue:1987
	__( 'Button Border Color', 'coming-soon' ),

	// Reference: src/components/ColOptions.vue:664
	__( 'Column Width', 'coming-soon' ),

	// Reference: src/components/ColOptions.vue:675
	// Reference: src/components/PostinfoOptions.vue:600
	// Reference: src/components/PostsOptions.vue:1484
	// Reference: src/components/ProductMetaOptions.vue:327
	// Reference: src/components/WCCartOptions.vue:496
	// Reference: src/components/WCCheckoutOptions.vue:764
	// Reference: src/components/WCCustomProductsGridOptions.vue:1077
	// Reference: src/views/GlobalCSS.vue:1958
	__( 'Layout', 'coming-soon' ),

	// Reference: src/components/ColOptions.vue:676
	// Reference: src/components/ContactFormOptions.vue:292
	// Reference: src/components/GiveawayOptions.vue:164
	// Reference: src/components/NavOptions.vue:574
	// Reference: src/components/SectionOptions.vue:388
	__( 'Advanced Styles', 'coming-soon' ),

	// Reference: src/components/ColOptions.vue:677
	// Reference: src/components/RowOptions.vue:676
	__( 'Content Alignment', 'coming-soon' ),

	// Reference: src/components/ColOptions.vue:678
	// Reference: src/components/NavOptions.vue:589
	// Reference: src/components/RowOptions.vue:677
	__( 'Simple', 'coming-soon' ),

	// Reference: src/components/ColOptions.vue:682
	// Reference: src/components/RowOptions.vue:681
	__( 'Display', 'coming-soon' ),

	// Reference: src/components/ColOptions.vue:683
	// Reference: src/components/RowOptions.vue:682
	__( 'Flex Direction', 'coming-soon' ),

	// Reference: src/components/ColOptions.vue:684
	// Reference: src/components/RowOptions.vue:683
	__( 'Justify Content', 'coming-soon' ),

	// Reference: src/components/ColOptions.vue:685
	// Reference: src/components/RowOptions.vue:684
	__( 'Align Items', 'coming-soon' ),

	// Reference: src/components/ColOptions.vue:686
	// Reference: src/components/RowOptions.vue:685
	// Reference: src/views/Layoutnav.vue:770
	__( 'Column', 'coming-soon' ),

	// Reference: src/components/ColOptions.vue:687
	// Reference: src/components/RowOptions.vue:686
	// Reference: src/views/Layoutnav.vue:769
	__( 'Row', 'coming-soon' ),

	// Reference: src/components/ColOptions.vue:688
	// Reference: src/components/RowOptions.vue:687
	__( 'Flex Start', 'coming-soon' ),

	// Reference: src/components/ColOptions.vue:689
	// Reference: src/components/RowOptions.vue:688
	__( 'Center', 'coming-soon' ),

	// Reference: src/components/ColOptions.vue:690
	// Reference: src/components/RowOptions.vue:689
	__( 'Flex End', 'coming-soon' ),

	// Reference: src/components/ColOptions.vue:692
	// Reference: src/components/RowOptions.vue:691
	__( 'Space Around', 'coming-soon' ),

	// Reference: src/components/ColOptions.vue:693
	// Reference: src/components/RowOptions.vue:692
	__( 'Space Evenly', 'coming-soon' ),

	// Reference: src/components/ColOptions.vue:694
	// Reference: src/components/RowOptions.vue:693
	__( 'Baseline', 'coming-soon' ),

	// Reference: src/components/ColOptions.vue:695
	// Reference: src/components/RowOptions.vue:694
	__( 'Stretch', 'coming-soon' ),

	// Reference: src/components/ColOptions.vue:697
	// Reference: src/components/RowOptions.vue:700
	// Reference: src/components/SectionOptions.vue:390
	// Reference: src/components/ShapeDividerControl.vue:346
	__( 'Shape Divider', 'coming-soon' ),

	// Reference: src/components/ColorPicker.vue:262
	__( 'Global Colors', 'coming-soon' ),

	// Reference: src/components/ColorPicker.vue:263
	__( 'Common Colors', 'coming-soon' ),

	// Reference: src/components/ColorPicker.vue:264
	__( 'Recently Used', 'coming-soon' ),

	// Reference: src/components/ColorPicker.vue:265
	__( 'Clear', 'coming-soon' ),

	// Reference: src/components/ColorPicker.vue:267
	__( 'Global Theme Colors', 'coming-soon' ),

	// Reference: src/components/ContactForm.vue:168
	__( 'Install Contact Form plugin:', 'coming-soon' ),

	// Reference: src/components/ContactForm.vue:171
	__( 'Contact Form', 'coming-soon' ),

	// Reference: src/components/ContactForm.vue:172
	// Reference: src/components/Giveaway.vue:173
	__( '(This shortcode will be rendered on the live preview.)', 'coming-soon' ),

	// Reference: src/components/ContactForm.vue:176
	// Reference: src/components/ContactFormOptions.vue:293
	__( 'Select a Form', 'coming-soon' ),

	// Reference: src/components/ContactForm.vue:177
	__( 'You can use WPForms to build contact forms, surveys, payment forms, and more with just a few clicks.', 'coming-soon' ),

	// Reference: src/components/ContactFormOptions.vue:295
	__( 'Select', 'coming-soon' ),

	// Reference: src/components/ContactFormOptions.vue:296
	__( 'Need to make changes? Edit the selected form.', 'coming-soon' ),

	// Reference: src/components/ContactFormOptions.vue:297
	__( '+ New Form', 'coming-soon' ),

	// Reference: src/components/ContactFormOptions.vue:298
	// Reference: src/components/GiveawayOptions.vue:170
	// Reference: src/views/SettingsGeneral.vue:225
	__( 'Show', 'coming-soon' ),

	// Reference: src/components/ContactFormOptions.vue:299
	// Reference: src/components/GiveawayOptions.vue:171
	__( 'Hide', 'coming-soon' ),

	// Reference: src/components/ContactFormOptions.vue:300
	// Reference: src/components/GiveawayOptions.vue:172
	__( 'Form Name', 'coming-soon' ),

	// Reference: src/components/ContactFormOptions.vue:301
	// Reference: src/components/GiveawayOptions.vue:173
	__( 'Form Description', 'coming-soon' ),

	// Reference: src/components/ContactFormOptions.vue:302
	// Reference: src/components/GiveawayOptions.vue:174
	// Reference: src/components/LoginOptions.vue:904
	// Reference: src/components/OptinFormOptions.vue:847
	__( 'Form', 'coming-soon' ),

	// Reference: src/components/ContactFormOptions.vue:303
	// Reference: src/components/GiveawayOptions.vue:175
	__( 'Display Options', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue:849
	__( 'Countdown Type', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue:850
	__( 'Visitor Timer (Evergreen)', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue:851
	__( 'DateTime Countdown', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue:852
	__( 'Set Timer For', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue:853
	__( 'End Date', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue:854
	__( 'End Time', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue:855
	__( 'Timezone', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue:861
	__( 'Action To Take On Expires', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue:862
	// Reference: src/components/OptinFormOptions.vue:863
	__( 'Show Message', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue:863
	// Reference: src/components/OptinFormOptions.vue:864
	__( 'Redirect', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue:864
	// Reference: src/components/OptinFormOptions.vue:865
	__( 'Message', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue:865
	// Reference: src/components/LoginOptions.vue:881
	// Reference: src/components/OptinFormOptions.vue:866
	__( 'Redirect URL', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue:866
	__( 'Customize Labels', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue:867
	__( 'Day Label', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue:868
	__( 'Hour Label', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue:869
	__( 'Minute Label', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue:870
	__( 'Second Label', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue:872
	__( 'Hours', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue:873
	__( 'Minutes', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue:874
	__( 'Seconds', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue:886
	__( 'Hightlight Color', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue:887
	// Reference: src/components/WCCartOptions.vue:519
	// Reference: src/components/WCCheckoutOptions.vue:787
	// Reference: src/components/WCCustomProductsGridOptions.vue:1100
	// Reference: src/views/GlobalCSS.vue:1963
	__( 'Label Color', 'coming-soon' ),

	// Reference: src/components/CountdownOptions.vue:888
	__( 'Restart', 'coming-soon' ),

	// Reference: src/components/CustomHTML.vue:45
	__( 'Enter Your HTML', 'coming-soon' ),

	// Reference: src/components/CustomHTMLOptions.vue:200
	// Reference: src/views/GlobalCSS.vue:1919
	// Reference: src/views/SetupDesign-Lite.vue:753
	__( 'Expand Editor', 'coming-soon' ),

	// Reference: src/components/CustomHTMLOptions.vue:201
	__( 'Custom Code', 'coming-soon' ),

	// Reference: src/components/CustomHTMLOptions.vue:202
	__( 'Edit Custom HMTL', 'coming-soon' ),

	// Reference: src/components/DeviceVisibilityControl.vue:58
	__( 'Device Visibility', 'coming-soon' ),

	// Reference: src/components/DeviceVisibilityControl.vue:59
	__( 'Hide on Desktop', 'coming-soon' ),

	// Reference: src/components/DeviceVisibilityControl.vue:60
	__( 'Hide on Mobile', 'coming-soon' ),

	// Reference: src/components/DisplaySectionControl.vue:187
	__( 'Z-Index', 'coming-soon' ),

	// Reference: src/components/DisplaySectionControl.vue:189
	__( 'Static', 'coming-soon' ),

	// Reference: src/components/DisplaySectionControl.vue:190
	__( 'Relative', 'coming-soon' ),

	// Reference: src/components/DisplaySectionControl.vue:192
	__( 'Absolute', 'coming-soon' ),

	// Reference: src/components/DisplaySectionControl.vue:193
	__( 'Sticky', 'coming-soon' ),

	// Reference: src/components/DisplaySectionControl.vue:198
	__( 'Offset', 'coming-soon' ),

	// Reference: src/components/DisplaySectionControl.vue:199
	__( 'Overflow', 'coming-soon' ),

	// Reference: src/components/DisplaySectionControl.vue:200
	// Reference: src/components/WCCustomProductsGridOptions.vue:1219
	__( 'Visible', 'coming-soon' ),

	// Reference: src/components/DisplaySectionControl.vue:201
	// Reference: src/components/WCCustomProductsGridOptions.vue:1222
	__( 'Hidden', 'coming-soon' ),

	// Reference: src/components/DividerOptions.vue:363
	__( 'Solid Line', 'coming-soon' ),

	// Reference: src/components/DividerOptions.vue:366
	__( 'Double', 'coming-soon' ),

	// Reference: src/components/DividerOptions.vue:368
	// Reference: src/components/GoogleMapsOptions.vue:226
	// Reference: src/components/HeightControl.vue:84
	// Reference: src/components/ShapeDividerControl.vue:371
	// Reference: src/components/SpacerOptions.vue:68
	__( 'Height', 'coming-soon' ),

	// Reference: src/components/DividerOptions.vue:369
	// Reference: src/components/SocialProfilesOptions.vue:692
	__( 'Icon Size', 'coming-soon' ),

	// Reference: src/components/DividerOptions.vue:376
	// Reference: src/components/FeatureOptions.vue:456
	// Reference: src/components/HeaderOptions.vue:468
	// Reference: src/components/IconFeatureOptions.vue:446
	// Reference: src/components/IconOptions.vue:220
	// Reference: src/components/MenuCartOptions.vue:187
	// Reference: src/components/PostnavigationOptions.vue:95
	// Reference: src/components/ProductPriceOptions.vue:182
	// Reference: src/components/ProgressBarOptions.vue:337
	// Reference: src/components/ShadowControl.vue:138
	// Reference: src/components/ShapeDividerControl.vue:369
	// Reference: src/components/SocialProfilesOptions.vue:714
	// Reference: src/components/TestimonialOptions.vue:540
	// Reference: src/components/TextOptions.vue:391
	__( 'Color', 'coming-soon' ),

	// Reference: src/components/DividerOptions.vue:377
	__( 'Add Element', 'coming-soon' ),

	// Reference: src/components/DividerOptions.vue:382
	// Reference: src/components/PostauthorboxOptions.vue:340
	__( 'HTML Tag', 'coming-soon' ),

	// Reference: src/components/DividerOptions.vue:383
	// Reference: src/components/PostauthorboxOptions.vue:341
	// Reference: src/components/PostsOptions.vue:1491
	__( 'H1', 'coming-soon' ),

	// Reference: src/components/DividerOptions.vue:384
	// Reference: src/components/PostauthorboxOptions.vue:342
	// Reference: src/components/PostsOptions.vue:1492
	__( 'H2', 'coming-soon' ),

	// Reference: src/components/DividerOptions.vue:385
	// Reference: src/components/PostauthorboxOptions.vue:343
	// Reference: src/components/PostsOptions.vue:1493
	__( 'H3', 'coming-soon' ),

	// Reference: src/components/DividerOptions.vue:386
	// Reference: src/components/PostauthorboxOptions.vue:344
	// Reference: src/components/PostsOptions.vue:1494
	__( 'H4', 'coming-soon' ),

	// Reference: src/components/DividerOptions.vue:387
	// Reference: src/components/HeaderOptions.vue:469
	// Reference: src/components/PostauthorboxOptions.vue:345
	// Reference: src/components/PostsOptions.vue:1495
	__( 'H5', 'coming-soon' ),

	// Reference: src/components/DividerOptions.vue:388
	// Reference: src/components/HeaderOptions.vue:470
	// Reference: src/components/PostauthorboxOptions.vue:346
	// Reference: src/components/PostsOptions.vue:1496
	__( 'H6', 'coming-soon' ),

	// Reference: src/components/DividerOptions.vue:389
	// Reference: src/components/PostauthorboxOptions.vue:348
	// Reference: src/components/PostsOptions.vue:1498
	__( 'span', 'coming-soon' ),

	// Reference: src/components/DynamicTextControl.vue:132
	// Reference: src/components/HeaderOptions.vue:471
	// Reference: src/components/PostcommentsOptions.vue:203
	// Reference: src/components/TextOptions.vue:392
	__( 'Insert Dynamic Text', 'coming-soon' ),

	// Reference: src/components/DynamicTextControl.vue:134
	__( 'Please enter date/time format', 'coming-soon' ),

	// Reference: src/components/DynamicTextControl.vue:135
	__( 'Please select date/time format', 'coming-soon' ),

	// Reference: src/components/DynamicTextControl.vue:136
	__( 'Insert', 'coming-soon' ),

	// Reference: src/components/DynamicTextControl.vue:137
	// Reference: src/components/Row.vue:1059
	// Reference: src/components/Section.vue:670
	// Reference: src/views/Layoutnav.vue:772
	// Reference: src/views/Setup.vue:1018
	__( 'Cancel', 'coming-soon' ),

	// Reference: src/components/DynamicTextControl.vue:138
	__( 'Dynamic Text Replacement', 'coming-soon' ),

	// Reference: src/components/DynamicTextControl.vue:139
	__( 'DateTime', 'coming-soon' ),

	// Reference: src/components/DynamicTextControl.vue:140
	__( 'Query Parameter', 'coming-soon' ),

	// Reference: src/components/DynamicTextControl.vue:141
	__( 'Today', 'coming-soon' ),

	// Reference: src/components/DynamicTextControl.vue:142
	__( 'Tomorrow', 'coming-soon' ),

	// Reference: src/components/DynamicTextControl.vue:143
	__( 'Today Date', 'coming-soon' ),

	// Reference: src/components/DynamicTextControl.vue:144
	__( 'Tomorrow Date', 'coming-soon' ),

	// Reference: src/components/DynamicTextControl.vue:145
	__( 'Month', 'coming-soon' ),

	// Reference: src/components/DynamicTextControl.vue:146
	__( 'Next Month', 'coming-soon' ),

	// Reference: src/components/DynamicTextControl.vue:147
	__( 'Year', 'coming-soon' ),

	// Reference: src/components/DynamicTextControl.vue:148
	__( 'Select Date Time Format', 'coming-soon' ),

	// Reference: src/components/DynamicTextControl.vue:149
	__( 'Query Parameters', 'coming-soon' ),

	// Reference: src/components/DynamicTextControl.vue:150
	__( 'Dynamic Text allows to create evergreen text. You can create date based dynamic text or pass in by query parameter. <a href="https://www.seedprod.com/docs/dynamic-text" target="_blank" class="sp-text-primary hover:sp-underline">Learn More</a>', 'coming-soon' ),

	// Reference: src/components/DynamicTextControl.vue:151
	__( 'Parameter Name', 'coming-soon' ),

	// Reference: src/components/DynamicTextControl.vue:152
	__( 'Default Value', 'coming-soon' ),

	// Reference: src/components/DynamicTextControl.vue:153
	__( 'Please enter parameter name', 'coming-soon' ),

	// Reference: src/components/DynamicTextControl.vue:154
	__( 'Don\'t see the date format you need? Click the Learn More link above to learn how to create any date.', 'coming-soon' ),

	// Reference: src/components/FeatureOptions.vue:447
	// Reference: src/components/IconFeatureOptions.vue:437
	// Reference: src/components/PostinfoOptions.vue:584
	// Reference: src/components/ProductMetaOptions.vue:330
	// Reference: src/components/ShapeDividerControl.vue:349
	// Reference: src/components/TestimonialOptions.vue:534
	// Reference: src/components/VideoOptions.vue:233
	// Reference: src/components/WCCustomProductsGridOptions.vue:1131
	__( 'Type', 'coming-soon' ),

	// Reference: src/components/FeatureOptions.vue:448
	// Reference: src/components/IconFeatureOptions.vue:438
	// Reference: src/components/ImageOptions.vue:706
	// Reference: src/components/PostfeaturedimageOptions.vue:641
	// Reference: src/components/PostinfoOptions.vue:601
	// Reference: src/components/PostsOptions.vue:1529
	// Reference: src/components/ProductFeaturedImageOptions.vue:641
	// Reference: src/components/ProductMetaOptions.vue:331
	// Reference: src/components/ProductRelatedOptions.vue:629
	// Reference: src/components/SocialSharingOptions.vue:395
	// Reference: src/components/TestimonialOptions.vue:545
	// Reference: src/components/UpsellsOptions.vue:629
	// Reference: src/components/WCCustomProductsGridOptions.vue:1167
	__( 'Image', 'coming-soon' ),

	// Reference: src/components/FeatureOptions.vue:450
	// Reference: src/components/IconFeatureOptions.vue:440
	// Reference: src/components/ImageOptions.vue:715
	// Reference: src/components/PostfeaturedimageOptions.vue:650
	// Reference: src/components/ProductFeaturedImageOptions.vue:650
	__( 'Image Size', 'coming-soon' ),

	// Reference: src/components/FeatureOptions.vue:452
	// Reference: src/components/IconFeatureOptions.vue:442
	__( 'Header Text', 'coming-soon' ),

	// Reference: src/components/FeatureOptions.vue:453
	// Reference: src/components/HeaderOptions.vue:452
	// Reference: src/components/IconFeatureOptions.vue:443
	__( 'Level', 'coming-soon' ),

	// Reference: src/components/FeatureOptions.vue:460
	__( 'Al Text', 'coming-soon' ),

	// Reference: src/components/FontAwesomePicker.vue:39
	__( 'Click to select an icon', 'coming-soon' ),

	// Reference: src/components/FontAwesomePicker.vue:40
	__( 'Search icons', 'coming-soon' ),

	// Reference: src/components/FontVariantControl.vue:37
	__( 'Select a Font Weight', 'coming-soon' ),

	// Reference: src/components/FontVariantControl.vue:38
	__( 'Normal 400', 'coming-soon' ),

	// Reference: src/components/FontVariantControl.vue:39
	__( 'Bold 700', 'coming-soon' ),

	// Reference: src/components/Giveaway.vue:169
	__( 'Install Giveaway plugin:', 'coming-soon' ),

	// Reference: src/components/Giveaway.vue:172
	__( 'Giveaway', 'coming-soon' ),

	// Reference: src/components/Giveaway.vue:177
	__( 'Select a Giveway', 'coming-soon' ),

	// Reference: src/components/Giveaway.vue:178
	__( 'You can use RafflePress to build viral giveaways in minutes and explode your email list.', 'coming-soon' ),

	// Reference: src/components/GiveawayOptions.vue:167
	__( 'Select a Giveaway', 'coming-soon' ),

	// Reference: src/components/GiveawayOptions.vue:168
	__( 'Need to make changes? Edit the selected giveaway.', 'coming-soon' ),

	// Reference: src/components/GiveawayOptions.vue:169
	__( '+ New Giveaway', 'coming-soon' ),

	// Reference: src/components/GoogleMapsOptions.vue:223
	__( 'Google Maps', 'coming-soon' ),

	// Reference: src/components/GoogleMapsOptions.vue:224
	__( 'Location', 'coming-soon' ),

	// Reference: src/components/GoogleMapsOptions.vue:225
	__( 'Zoom', 'coming-soon' ),

	// Reference: src/components/HeaderOptions.vue:447
	__( 'Headline', 'coming-soon' ),

	// Reference: src/components/HeaderOptions.vue:453
	__( 'h1', 'coming-soon' ),

	// Reference: src/components/HeaderOptions.vue:454
	__( 'h2', 'coming-soon' ),

	// Reference: src/components/HeaderOptions.vue:455
	__( 'h3', 'coming-soon' ),

	// Reference: src/components/HeaderOptions.vue:456
	__( 'h4', 'coming-soon' ),

	// Reference: src/components/IconPicker.vue:242
	__( 'All Icons', 'coming-soon' ),

	// Reference: src/components/IconPicker.vue:243
	__( 'Font Awesome', 'coming-soon' ),

	// Reference: src/components/IconPicker.vue:244
	__( 'Search icons...', 'coming-soon' ),

	// Reference: src/components/IconPicker.vue:245
	// Reference: src/components/PostinfoOptions.vue:599
	__( 'Choose Icon', 'coming-soon' ),

	// Reference: src/components/IconPicker.vue:246
	__( 'Icon Library', 'coming-soon' ),

	// Reference: src/components/ImageControl.vue:253
	__( 'Choose New Image', 'coming-soon' ),

	// Reference: src/components/ImageControl.vue:258
	__( 'Use Your', 'coming-soon' ),

	// Reference: src/components/ImageControl.vue:259
	__( 'Own Image', 'coming-soon' ),

	// Reference: src/components/ImageControl.vue:260
	// Reference: src/components/Row.vue:1055
	// Reference: src/components/Section.vue:667
	// Reference: src/views/BuilderView.vue:1052
	__( 'or', 'coming-soon' ),

	// Reference: src/components/ImageControl.vue:261
	__( 'Stock Images Library', 'coming-soon' ),

	// Reference: src/components/ImageControl.vue:262
	// Reference: src/components/WCCustomProductsGridOptions.vue:1221
	__( 'Search', 'coming-soon' ),

	// Reference: src/components/ImageControl.vue:263
	__( 'Use a', 'coming-soon' ),

	// Reference: src/components/ImageControl.vue:264
	__( 'Stock Image', 'coming-soon' ),

	// Reference: src/components/ImageControl.vue:265
	__( 'Search images...', 'coming-soon' ),

	// Reference: src/components/ImageOptions.vue:709
	// Reference: src/components/PostfeaturedimageOptions.vue:644
	// Reference: src/components/ProductFeaturedImageOptions.vue:644
	__( 'Image Border', 'coming-soon' ),

	// Reference: src/components/ImageOptions.vue:714
	// Reference: src/components/PostfeaturedimageOptions.vue:649
	// Reference: src/components/ProductFeaturedImageOptions.vue:649
	__( 'Alt Text', 'coming-soon' ),

	// Reference: src/components/ImageOptions.vue:725
	// Reference: src/components/PostfeaturedimageOptions.vue:660
	// Reference: src/components/PostsOptions.vue:1542
	// Reference: src/components/ProductFeaturedImageOptions.vue:660
	// Reference: src/components/ProductRelatedOptions.vue:642
	// Reference: src/components/ShadowControl.vue:146
	// Reference: src/components/UpsellsOptions.vue:642
	// Reference: src/components/WCCustomProductsGridOptions.vue:1180
	__( 'Bottom Drop Shadow', 'coming-soon' ),

	// Reference: src/components/ImageOptions.vue:732
	// Reference: src/components/PostfeaturedimageOptions.vue:667
	// Reference: src/components/PostsOptions.vue:1549
	// Reference: src/components/PricingTableOptions.vue:1313
	// Reference: src/components/ProductFeaturedImageOptions.vue:667
	// Reference: src/components/ProductRelatedOptions.vue:649
	// Reference: src/components/UpsellsOptions.vue:649
	// Reference: src/components/WCCustomProductsGridOptions.vue:1187
	__( 'Image Whitespace Padding', 'coming-soon' ),

	// Reference: src/components/ImageOptions.vue:736
	// Reference: src/components/PostfeaturedimageOptions.vue:671
	// Reference: src/components/ProductFeaturedImageOptions.vue:671
	__( 'No Follow', 'coming-soon' ),

	// Reference: src/components/ImageOptions.vue:737
	__( 'Link Type', 'coming-soon' ),

	// Reference: src/components/ImageOptions.vue:738
	__( 'Custom Link', 'coming-soon' ),

	// Reference: src/components/ImageOptions.vue:739
	__( 'Media - Lightbox', 'coming-soon' ),

	// Reference: src/components/ImageOptions.vue:741
	__( 'Object Fit', 'coming-soon' ),

	// Reference: src/components/ImageOptions.vue:743
	__( 'Fill', 'coming-soon' ),

	// Reference: src/components/ImageOptions.vue:746
	__( 'Border Radius Unit', 'coming-soon' ),

	// Reference: src/components/ListTable.vue:470
	__( 'Bulk Actions', 'coming-soon' ),

	// Reference: src/components/ListTable.vue:471
	// Reference: src/components/WpWidgetBlockOptions.vue:185
	__( 'Apply', 'coming-soon' ),

	// Reference: src/components/ListTable.vue:472
	__( 'items', 'coming-soon' ),

	// Reference: src/components/ListTable.vue:473
	__( 'No items found.', 'coming-soon' ),

	// Reference: src/components/ListTable.vue:475
	__( 'Select bulk action', 'coming-soon' ),

	// Reference: src/components/LiteCTABuilder.vue:46
	// Reference: src/components/LiteCTASubscribers.vue:93
	// Reference: src/components/LiteCTATemplates.vue:45
	// Reference: src/components/SettingsLiteCTA.vue:153
	// Reference: src/components/ThemeBuilderUpsell.vue:152
	// Reference: src/components/UpgradeCTABuilder.vue:45
	__( 'Dismiss this message', 'coming-soon' ),

	// Reference: src/components/LiteCTABuilder.vue:47
	// Reference: src/components/LiteCTASubscribers.vue:94
	// Reference: src/components/LiteCTATemplates.vue:46
	// Reference: src/components/SettingsLiteCTA.vue:154
	// Reference: src/components/ThemeBuilderUpsell.vue:153
	// Reference: src/components/UpgradeCTABuilder.vue:46
	__( 'Get SeedProd Lite and Unlock all the Powerful Features', 'coming-soon' ),

	// Reference: src/components/LiteCTABuilder.vue:51
	// Reference: src/components/UpgradeCTABuilder.vue:50
	__( 'Thanks for being a loyal SeedProd Lite user. Upgrade to
SeedProd Lite to unlock all the awesome features and
experience why SeedProd is the best WordPress landing
page plugin.', 'coming-soon' ),

	// Reference: src/components/LiteCTABuilder.vue:58
	// Reference: src/components/LiteCTASubscribers.vue:105
	// Reference: src/components/LiteCTATemplates.vue:57
	// Reference: src/components/SettingsLiteCTA.vue:165
	// Reference: src/components/ThemeBuilderUpsell.vue:164
	// Reference: src/components/UpgradeCTABuilder.vue:57
	__( 'Pro Features:', 'coming-soon' ),

	// Reference: src/components/LiteCTABuilder.vue:59
	// Reference: src/components/LiteCTATemplates.vue:58
	// Reference: src/components/UpgradeCTABuilder.vue:58
	__( 'Drag & Drop Page Builder', 'coming-soon' ),

	// Reference: src/components/LiteCTABuilder.vue:60
	// Reference: src/components/SettingsLiteCTA.vue:167
	// Reference: src/components/UpgradeCTABuilder.vue:59
	__( '80+ PRO Page Blocks', 'coming-soon' ),

	// Reference: src/components/LiteCTABuilder.vue:61
	// Reference: src/components/UpgradeCTABuilder.vue:60
	__( 'PRO Email Marketing Integrations', 'coming-soon' ),

	// Reference: src/components/LiteCTABuilder.vue:65
	// Reference: src/components/LiteCTASubscribers.vue:112
	// Reference: src/components/SettingsLiteCTA.vue:172
	// Reference: src/components/ThemeBuilderUpsell.vue:171
	// Reference: src/components/UpgradeCTABuilder.vue:64
	__( 'Custom 404 Pages', 'coming-soon' ),

	// Reference: src/components/LiteCTABuilder.vue:66
	// Reference: src/components/LiteCTASubscribers.vue:113
	// Reference: src/components/ThemeBuilderUpsell.vue:172
	// Reference: src/components/UpgradeCTABuilder.vue:65
	__( 'Page Access Controls', 'coming-soon' ),

	// Reference: src/components/LiteCTABuilder.vue:67
	// Reference: src/components/SettingsLiteCTA.vue:174
	// Reference: src/components/UpgradeCTABuilder.vue:66
	__( '200+ PRO Page Templates', 'coming-soon' ),

	// Reference: src/components/LiteCTABuilder.vue:68
	// Reference: src/components/SettingsLiteCTA.vue:175
	// Reference: src/components/UpgradeCTABuilder.vue:67
	__( 'PRO Smart Sections', 'coming-soon' ),

	// Reference: src/components/LiteCTABuilder.vue:72
	// Reference: src/components/LiteCTASubscribers.vue:119
	// Reference: src/components/ThemeBuilderUpsell.vue:175
	// Reference: src/components/UpgradeCTABuilder.vue:71
	__( 'Email Subscriber Management', 'coming-soon' ),

	// Reference: src/components/LiteCTABuilder.vue:73
	// Reference: src/components/LiteCTASubscribers.vue:120
	// Reference: src/components/SettingsLiteCTA.vue:180
	// Reference: src/components/ThemeBuilderUpsell.vue:179
	// Reference: src/components/UpgradeCTABuilder.vue:72
	// Reference: src/views/TemplateChooser-Lite.vue:1210
	__( 'Saved Templates', 'coming-soon' ),

	// Reference: src/components/LiteCTABuilder.vue:74
	// Reference: src/components/LiteCTASubscribers.vue:121
	// Reference: src/components/LiteCTATemplates.vue:73
	// Reference: src/components/SettingsLiteCTA.vue:181
	// Reference: src/components/ThemeBuilderUpsell.vue:180
	// Reference: src/components/UpgradeCTABuilder.vue:73
	__( 'Plus much more...', 'coming-soon' ),

	// Reference: src/components/LiteCTABuilder.vue:76
	// Reference: src/components/LiteCTASubscribers.vue:122
	// Reference: src/components/LiteCTATemplates.vue:74
	// Reference: src/components/SettingsLiteCTA.vue:182
	// Reference: src/components/ThemeBuilderUpsell.vue:181
	// Reference: src/components/UpgradeCTABuilder.vue:75
	__( 'Bonus:', 'coming-soon' ),

	// Reference: src/components/LiteCTABuilder.vue:77
	// Reference: src/components/LiteCTASubscribers.vue:123
	// Reference: src/components/LiteCTATemplates.vue:75
	// Reference: src/components/SettingsLiteCTA.vue:183
	// Reference: src/components/ThemeBuilderUpsell.vue:182
	// Reference: src/components/UpgradeCTABuilder.vue:76
	__( 'SeedProd Lite users get', 'coming-soon' ),

	// Reference: src/components/LiteCTABuilder.vue:78
	// Reference: src/components/LiteCTASubscribers.vue:124
	// Reference: src/components/LiteCTATemplates.vue:76
	// Reference: src/components/SettingsLiteCTA.vue:184
	// Reference: src/components/ThemeBuilderUpsell.vue:183
	// Reference: src/components/UpgradeCTABuilder.vue:77
	__( 'a discount off the regular price', 'coming-soon' ),

	// Reference: src/components/LiteCTABuilder.vue:82
	// Reference: src/components/LiteCTASubscribers.vue:128
	// Reference: src/components/LiteCTATemplates.vue:80
	// Reference: src/components/SettingsLiteCTA.vue:188
	// Reference: src/components/ThemeBuilderUpsell.vue:187
	// Reference: src/components/UpgradeCTABuilder.vue:81
	__( 'automatically applied at checkout.', 'coming-soon' ),

	// Reference: src/components/LiteCTABuilder.vue:86
	// Reference: src/components/LiteCTASubscribers.vue:132
	// Reference: src/components/LiteCTATemplates.vue:84
	// Reference: src/components/SettingsLiteCTA.vue:192
	// Reference: src/components/ThemeBuilderUpsell.vue:191
	// Reference: src/components/UpgradeCTABuilder.vue:85
	__( 'Get SeedProd Lite Today and Unlock all the Powerful Features »', 'coming-soon' ),

	// Reference: src/components/LiteCTASubscribers.vue:106
	// Reference: src/components/ThemeBuilderUpsell.vue:165
	__( 'Filter by Page', 'coming-soon' ),

	// Reference: src/components/LiteCTASubscribers.vue:107
	// Reference: src/components/ThemeBuilderUpsell.vue:166
	__( 'Export to a CSV File', 'coming-soon' ),

	// Reference: src/components/LiteCTASubscribers.vue:108
	// Reference: src/components/ThemeBuilderUpsell.vue:167
	__( 'Premium Email Marketing Integrations', 'coming-soon' ),

	// Reference: src/components/LiteCTASubscribers.vue:114
	// Reference: src/components/ThemeBuilderUpsell.vue:173
	__( 'Subscribers Over Time', 'coming-soon' ),

	// Reference: src/components/LiteCTASubscribers.vue:115
	// Reference: src/components/ThemeBuilderUpsell.vue:174
	__( 'See Name and Emails', 'coming-soon' ),

	// Reference: src/components/LiteCTATemplates.vue:59
	__( 'More Premium Blocks', 'coming-soon' ),

	// Reference: src/components/LiteCTATemplates.vue:60
	__( 'Capture Emails and Leads', 'coming-soon' ),

	// Reference: src/components/LiteCTATemplates.vue:64
	__( 'Marketing & CRM Integrations', 'coming-soon' ),

	// Reference: src/components/LiteCTATemplates.vue:65
	__( 'Maintenance Access Controls', 'coming-soon' ),

	// Reference: src/components/LiteCTATemplates.vue:66
	__( 'Growing Library of Templates', 'coming-soon' ),

	// Reference: src/components/LiteCTATemplates.vue:67
	__( 'Smart Sections', 'coming-soon' ),

	// Reference: src/components/LiteCTATemplates.vue:71
	__( 'More Design Controls', 'coming-soon' ),

	// Reference: src/components/LiteCTATemplates.vue:72
	__( 'Coming Soon Access Controls', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:877
	// Reference: src/components/OptinFormOptions.vue:848
	// Reference: src/components/WCCartOptions.vue:498
	// Reference: src/components/WCCheckoutOptions.vue:766
	// Reference: src/components/WCCustomProductsGridOptions.vue:1079
	__( 'Fields', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:882
	__( 'Label for User field', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:883
	__( 'Placeholder for User field', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:884
	__( 'Label for Password field', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:885
	__( 'Placeholder for Password field', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:887
	// Reference: src/components/ProductMetaOptions.vue:342
	__( 'Link Color', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:888
	__( 'Link Hover Color', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:889
	__( 'Label Text Color', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:890
	// Reference: src/components/OptinFormOptions.vue:880
	// Reference: src/components/WCCartOptions.vue:516
	// Reference: src/components/WCCheckoutOptions.vue:784
	// Reference: src/components/WCCustomProductsGridOptions.vue:1097
	// Reference: src/views/GlobalCSS.vue:1965
	__( 'Field Text Color', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:891
	// Reference: src/components/OptinFormOptions.vue:879
	// Reference: src/components/WCCartOptions.vue:515
	// Reference: src/components/WCCheckoutOptions.vue:783
	// Reference: src/components/WCCustomProductsGridOptions.vue:1096
	// Reference: src/views/GlobalCSS.vue:1966
	__( 'Field Background Color', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:892
	// Reference: src/components/OptinFormOptions.vue:881
	// Reference: src/components/WCCartOptions.vue:517
	// Reference: src/components/WCCheckoutOptions.vue:785
	// Reference: src/components/WCCustomProductsGridOptions.vue:1098
	// Reference: src/views/GlobalCSS.vue:1967
	__( 'Field Border Color', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:894
	__( 'Button Background Color', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:895
	__( 'Field Size', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:896
	// Reference: src/components/WCCartOptions.vue:521
	// Reference: src/components/WCCheckoutOptions.vue:789
	// Reference: src/components/WCCustomProductsGridOptions.vue:1102
	__( 'Row Spacing', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:897
	__( 'Label Spacing', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:898
	// Reference: src/components/WCCartOptions.vue:518
	// Reference: src/components/WCCheckoutOptions.vue:786
	// Reference: src/components/WCCustomProductsGridOptions.vue:1099
	// Reference: src/views/GlobalCSS.vue:1972
	__( 'Field Border Width', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:899
	__( 'Field Border Radius', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:900
	// Reference: src/components/ProductRelatedOptions.vue:623
	// Reference: src/components/UpsellsOptions.vue:623
	// Reference: src/components/WCCustomProductsGridOptions.vue:1161
	__( 'Button Size', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:902
	// Reference: src/components/OptinFormOptions.vue:846
	__( 'Success Action', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:903
	__( 'Additional Options', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:906
	__( 'Remember User Label', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:907
	__( 'Lost Password Link Text', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:908
	// Reference: src/views/GlobalCSS.vue:1935
	// Reference: src/views/SetupDesign-Lite.vue:755
	__( 'Colors', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:909
	// Reference: src/components/WCCartOptions.vue:520
	// Reference: src/components/WCCheckoutOptions.vue:788
	// Reference: src/components/WCCustomProductsGridOptions.vue:1101
	__( 'Label Font', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:910
	__( 'Label Font Weight', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:911
	__( 'Field Font', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:912
	__( 'Field Font Weight', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:913
	// Reference: src/views/GlobalCSS.vue:1986
	__( 'Button Font', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:914
	__( 'Button Font Weight', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:915
	__( 'Logged In Text', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:916
	__( 'This text displays in place of a form if the user is already logged in. {user} will be replaced by the user\'s display name.', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:917
	__( '(e.g. \'Remember Me\')', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:918
	__( '(e.g. \'Lost your password?\')', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:919
	__( 'Button Border Radius', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:920
	__( 'Field Width', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:926
	__( 'Label Text Size', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:928
	// Reference: src/components/OptinFormOptions.vue:882
	// Reference: src/components/WCCartOptions.vue:504
	// Reference: src/components/WCCheckoutOptions.vue:772
	// Reference: src/components/WCCustomProductsGridOptions.vue:1085
	__( 'Light Input Field', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:929
	// Reference: src/components/OptinFormOptions.vue:883
	// Reference: src/components/WCCartOptions.vue:505
	// Reference: src/components/WCCheckoutOptions.vue:773
	// Reference: src/components/WCCustomProductsGridOptions.vue:1086
	__( 'No Border Input Field', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:930
	// Reference: src/components/OptinFormOptions.vue:884
	// Reference: src/components/WCCartOptions.vue:506
	// Reference: src/components/WCCheckoutOptions.vue:774
	// Reference: src/components/WCCustomProductsGridOptions.vue:1087
	__( 'Wide Border Input Field', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:931
	// Reference: src/components/OptinFormOptions.vue:885
	// Reference: src/components/WCCartOptions.vue:507
	// Reference: src/components/WCCheckoutOptions.vue:775
	// Reference: src/components/WCCustomProductsGridOptions.vue:1088
	__( 'Inner Shadow Input Field', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:932
	// Reference: src/components/OptinFormOptions.vue:886
	// Reference: src/components/WCCartOptions.vue:508
	// Reference: src/components/WCCheckoutOptions.vue:776
	// Reference: src/components/WCCustomProductsGridOptions.vue:1089
	__( 'Grey Input Field', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:933
	// Reference: src/components/OptinFormOptions.vue:887
	// Reference: src/components/WCCartOptions.vue:509
	// Reference: src/components/WCCheckoutOptions.vue:777
	// Reference: src/components/WCCustomProductsGridOptions.vue:1090
	__( 'Dark Input Field', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:934
	// Reference: src/components/OptinFormOptions.vue:888
	// Reference: src/components/WCCartOptions.vue:510
	// Reference: src/components/WCCheckoutOptions.vue:778
	// Reference: src/components/WCCustomProductsGridOptions.vue:1091
	__( 'Bottom Border Field', 'coming-soon' ),

	// Reference: src/components/LoginOptions.vue:935
	// Reference: src/components/OptinFormOptions.vue:889
	// Reference: src/components/WCCartOptions.vue:511
	// Reference: src/components/WCCheckoutOptions.vue:779
	// Reference: src/components/WCCustomProductsGridOptions.vue:1092
	__( 'Transparent Input Field', 'coming-soon' ),

	// Reference: src/components/MarginControl.vue:332
	__( 'Margin', 'coming-soon' ),

	// Reference: src/components/MenuCartOptions.vue:184
	__( 'Hide on Empty', 'coming-soon' ),

	// Reference: src/components/MenuCartOptions.vue:186
	__( 'Show Subtotal', 'coming-soon' ),

	// Reference: src/components/MenuCartOptions.vue:188
	__( 'Badge Color', 'coming-soon' ),

	// Reference: src/components/MenuCartOptions.vue:189
	__( 'Badge Text Color', 'coming-soon' ),

	// Reference: src/components/Modal.vue:33
	__( 'default header', 'coming-soon' ),

	// Reference: src/components/Modal.vue:34
	__( 'default body', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue:580
	__( 'URL Link', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue:583
	__( 'Mobile Menu', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue:584
	__( 'On', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue:585
	__( 'Off', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue:586
	__( 'Hover Color', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue:588
	__( 'Menu Type', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue:590
	__( 'WordPress Menu', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue:591
	__( 'Sub Menu Background Color', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue:592
	__( 'Sub Menu Border Radius', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue:593
	__( 'Sub Menu Line Height', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue:594
	__( 'Sub Menu Border Width', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue:595
	__( 'Sub Menu Border Color', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue:596
	__( 'Sub Menu Text Color', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue:597
	__( 'Sub Menu Hover Color', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue:598
	__( 'Sub Menu', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue:607
	__( 'Menus', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue:608
	// Reference: src/components/PostauthorboxOptions.vue:359
	__( 'Go to the', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue:609
	__( 'Menus Screen', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue:610
	__( 'to manage your menus', 'coming-soon' ),

	// Reference: src/components/NavOptions.vue:611
	__( 'There are no menus in your site.', 'coming-soon' ),

	// Reference: src/components/OptinFormOptions.vue:845
	__( 'Submit Button', 'coming-soon' ),

	// Reference: src/components/OptinFormOptions.vue:850
	// Reference: src/components/SocialSharingOptions.vue:393
	// Reference: src/components/StarRatingOptions.vue:301
	// Reference: src/views/GlobalCSS.vue:1962
	__( 'Label', 'coming-soon' ),

	// Reference: src/components/OptinFormOptions.vue:852
	__( 'Required', 'coming-soon' ),

	// Reference: src/components/OptinFormOptions.vue:861
	__( 'Input Sizes', 'coming-soon' ),

	// Reference: src/components/OptinFormOptions.vue:862
	__( 'Action To Take', 'coming-soon' ),

	// Reference: src/components/OptinFormOptions.vue:868
	// Reference: src/components/TypographyControl.vue:277
	// Reference: src/components/WCCartOptions.vue:538
	// Reference: src/components/WCCheckoutOptions.vue:806
	// Reference: src/components/WCCustomProductsGridOptions.vue:1119
	__( 'Font Family', 'coming-soon' ),

	// Reference: src/components/OptinFormOptions.vue:870
	__( 'Remove Inline Padding', 'coming-soon' ),

	// Reference: src/components/OptinFormOptions.vue:890
	__( 'Button text', 'coming-soon' ),

	// Reference: src/components/PostauthorboxOptions.vue:337
	__( 'Profile Picture', 'coming-soon' ),

	// Reference: src/components/PostauthorboxOptions.vue:338
	__( 'Display Name', 'coming-soon' ),

	// Reference: src/components/PostauthorboxOptions.vue:339
	__( 'Biography', 'coming-soon' ),

	// Reference: src/components/PostauthorboxOptions.vue:347
	// Reference: src/components/PostsOptions.vue:1497
	__( 'div', 'coming-soon' ),

	// Reference: src/components/PostauthorboxOptions.vue:349
	// Reference: src/components/PostsOptions.vue:1499
	__( 'p', 'coming-soon' ),

	// Reference: src/components/PostauthorboxOptions.vue:352
	__( 'Website', 'coming-soon' ),

	// Reference: src/components/PostauthorboxOptions.vue:353
	__( 'Archive Posts', 'coming-soon' ),

	// Reference: src/components/PostauthorboxOptions.vue:355
	// Reference: src/components/TestimonialOptions.vue:541
	__( 'Name Color', 'coming-soon' ),

	// Reference: src/components/PostauthorboxOptions.vue:356
	__( 'Biography Color', 'coming-soon' ),

	// Reference: src/components/PostauthorboxOptions.vue:360
	__( 'Profile Screen', 'coming-soon' ),

	// Reference: src/components/PostauthorboxOptions.vue:361
	__( 'to manage your profile.', 'coming-soon' ),

	// Reference: src/components/PostcommentsOptions.vue:201
	__( 'Content Policy', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue:571
	__( 'Author', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue:574
	__( 'Comments', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue:577
	__( 'Avatar', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue:581
	// Reference: src/components/ProductMetaOptions.vue:336
	__( 'Layout Settings', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue:586
	// Reference: src/components/ProductMetaOptions.vue:332
	__( 'Add Item', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue:587
	// Reference: src/components/ProductMetaOptions.vue:333
	__( 'Caption', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue:588
	__( 'Date Format', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue:589
	__( 'May 14, 2021 (F j, Y)', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue:590
	__( '2021-05-14 (Y-m-d)', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue:591
	__( '05/14/2021 (m/d/Y)', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue:592
	__( '14/05/2021 (d/m/Y)', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue:595
	__( 'Custom Date Format', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue:596
	__( 'Use the letters: l D d j S F m M n Y y', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue:604
	// Reference: src/components/ProductMetaOptions.vue:339
	// Reference: src/components/ProductRelatedOptions.vue:618
	// Reference: src/components/TypographyControl.vue:282
	// Reference: src/components/UpsellsOptions.vue:618
	// Reference: src/components/WCCustomProductsGridOptions.vue:1154
	__( 'Alignment', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue:609
	__( 'Modified Date', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue:610
	__( 'Modified Time', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue:611
	__( 'Tags', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue:612
	__( 'Category', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue:613
	__( 'Terms', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue:614
	__( 'Time Format', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue:615
	__( '9:15 am (g:i a)', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue:616
	__( '9:15 AM (g:i A)', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue:617
	__( '09:15 (H:i)', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue:618
	__( 'Custom Time Format', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue:619
	__( 'Use the letters: g G H i a A', 'coming-soon' ),

	// Reference: src/components/PostinfoOptions.vue:620
	__( 'Show Icons', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1456
	__( 'Posts Query', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1457
	__( 'Query Type', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1460
	__( 'Manual', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1461
	__( 'Query By Post Type', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1462
	__( 'Include Selected Post Type(s)', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1463
	__( '- Select Post Type(s) -', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1464
	__( 'Query By Category', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1465
	// Reference: src/components/WCCustomProductsGridOptions.vue:1215
	__( 'Include Selected Categories', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1466
	// Reference: src/components/WCCustomProductsGridOptions.vue:1200
	__( '- Select Categories -', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1467
	__( 'Query By Tag(s)', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1468
	__( 'Include Selected Tag(s)', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1469
	__( '- Select Tag(s) -', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1470
	__( 'Query By Author(s)', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1471
	__( 'Include Selected Author(s)', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1472
	__( '- Select Author(s) -', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1473
	// Reference: src/components/ProductRelatedOptions.vue:614
	// Reference: src/components/UpsellsOptions.vue:614
	// Reference: src/components/WCCustomProductsGridOptions.vue:1142
	__( 'Order By', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1474
	// Reference: src/components/ProductRelatedOptions.vue:651
	// Reference: src/components/UpsellsOptions.vue:651
	// Reference: src/components/WCCustomProductsGridOptions.vue:1189
	__( '- Select Options -', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1476
	__( 'Date Last Modified', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1477
	// Reference: src/components/ProductRelatedOptions.vue:658
	// Reference: src/components/TestimonialOptions.vue:548
	// Reference: src/components/UpsellsOptions.vue:658
	// Reference: src/components/WCCustomProductsGridOptions.vue:1196
	__( 'Title', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1478
	__( 'Comment Count', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1479
	// Reference: src/components/ProductRelatedOptions.vue:654
	// Reference: src/components/UpsellsOptions.vue:654
	// Reference: src/components/WCCustomProductsGridOptions.vue:1192
	__( 'Menu Order', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1480
	// Reference: src/components/ProductRelatedOptions.vue:615
	// Reference: src/components/UpsellsOptions.vue:615
	// Reference: src/components/WCCustomProductsGridOptions.vue:1143
	__( 'Order', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1481
	// Reference: src/components/ProductRelatedOptions.vue:616
	// Reference: src/components/UpsellsOptions.vue:616
	// Reference: src/components/WCCustomProductsGridOptions.vue:1151
	__( 'ASC', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1482
	// Reference: src/components/ProductRelatedOptions.vue:617
	// Reference: src/components/UpsellsOptions.vue:617
	// Reference: src/components/WCCustomProductsGridOptions.vue:1152
	__( 'DESC', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1483
	__( 'Query Params', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1485
	// Reference: src/components/ProductRelatedOptions.vue:613
	// Reference: src/components/UpsellsOptions.vue:613
	// Reference: src/components/WCCustomProductsGridOptions.vue:1126
	__( 'Columns', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1486
	// Reference: src/components/WCCustomProductsGridOptions.vue:1128
	__( 'Pagination', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1487
	__( 'Number Per Pages', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1488
	__( 'Show Feature Image', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1489
	__( 'Show Title', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1490
	__( 'Title Tag', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1500
	__( 'Show Meta', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1501
	__( 'Show Date Modified', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1502
	__( 'Show Author', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1503
	__( 'Show Date', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1504
	__( 'Show Time', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1505
	__( 'Show Comment Count', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1506
	__( 'Separator', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1507
	__( 'Show Excerpt', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1508
	__( 'Excerpt Length', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1509
	__( 'Show Read More', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1514
	__( 'Title Color', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1515
	__( 'Meta Text', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1516
	__( 'Meta Text Color', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1517
	__( 'Excerpt', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1518
	__( 'Excerpt Color', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1519
	__( 'Read More Text', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1520
	__( 'Read More Text Color', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1521
	__( 'Pagination Color', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1522
	__( 'Space Bottom', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1543
	// Reference: src/components/ProductRelatedOptions.vue:643
	// Reference: src/components/UpsellsOptions.vue:643
	// Reference: src/components/WCCustomProductsGridOptions.vue:1181
	__( 'Image Border Color', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1544
	// Reference: src/components/ProductRelatedOptions.vue:644
	// Reference: src/components/UpsellsOptions.vue:644
	// Reference: src/components/WCCustomProductsGridOptions.vue:1182
	__( 'Image Border Width', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1554
	__( 'Post Padding', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1555
	__( 'Image Margin', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1556
	__( 'Post', 'coming-soon' ),

	// Reference: src/components/PostsOptions.vue:1557
	__( 'Post Background Color', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1232
	__( 'Features List', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1234
	__( 'Plan Name', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1236
	__( 'Currency Symbol', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1239
	// Reference: src/components/WCCartOptions.vue:499
	// Reference: src/components/WCCheckoutOptions.vue:767
	// Reference: src/components/WCCustomProductsGridOptions.vue:1080
	// Reference: src/views/GlobalCSS.vue:1960
	// Reference: src/views/SetupDesign-Lite.vue:748
	__( 'Buttons', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1240
	__( 'Plan Name Typography', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1241
	__( 'Plan Name Color', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1242
	__( 'Top Button Size', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1243
	__( 'Top Button', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1246
	__( 'Bottom Button', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1247
	// Reference: src/components/WCCustomProductsGridOptions.vue:1156
	__( 'Price', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1248
	__( 'Top Size', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1249
	__( 'Top Button Before Text Icon', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1250
	__( 'Top Button After Text Icon', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1251
	__( 'Regular Price Color', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1255
	__( '$ Dollar', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1256
	__( '€ Euro', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1257
	__( '฿ Baht', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1258
	__( '₣ Franc', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1259
	__( 'ƒ Guilder', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1260
	__( 'kr Krona', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1261
	__( '₤ Lira', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1262
	__( '₧ Peseta', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1263
	__( '₱ Peso', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1264
	__( '£ Pound Sterling', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1265
	__( 'R$ Real', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1266
	__( '₽ Ruble', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1267
	__( '₨ Rupee', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1268
	__( '₹ Rupee (Indian)', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1269
	__( '₪ Shekel', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1270
	__( '¥ Yen/Yuan', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1271
	__( '₩ Won', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1273
	__( 'Custom Symbol', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1274
	__( 'Period', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1275
	__( 'Show Regular Price', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1276
	__( 'Regular Price', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1277
	__( 'Regular Price Label', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1278
	// Reference: src/components/WCCustomProductsGridOptions.vue:1155
	__( 'Description', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1279
	__( 'Show Top Button', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1280
	__( 'Top Button Text', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1281
	__( 'Top Button Link', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1284
	__( 'Show Bottom Button', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1285
	__( 'Bottom Button Text', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1286
	__( 'Bottom Button Link', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1287
	__( 'Description Color', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1289
	__( 'Top Button Color', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1290
	__( 'Features List Color', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1293
	__( 'Bottom Button Color', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1294
	__( 'Bottom Button Size', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1295
	__( 'Bottom Button Before Text Icon', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1299
	__( 'Bottom Button After Text Icon', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1303
	// Reference: src/components/ProductRelatedOptions.vue:619
	// Reference: src/components/UpsellsOptions.vue:619
	// Reference: src/components/WCCustomProductsGridOptions.vue:1157
	__( 'Price Color', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1304
	__( 'Price Superscript', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1305
	__( 'Price Superscript Top', 'coming-soon' ),

	// Reference: src/components/PricingTableOptions.vue:1306
	__( 'Block', 'coming-soon' ),

	// Reference: src/components/ProductDataTabsOptions.vue:329
	__( 'Tab', 'coming-soon' ),

	// Reference: src/components/ProductDataTabsOptions.vue:331
	__( 'Panel', 'coming-soon' ),

	// Reference: src/components/ProductDataTabsOptions.vue:332
	__( 'Heading', 'coming-soon' ),

	// Reference: src/components/ProductDataTabsOptions.vue:333
	__( 'Tabs', 'coming-soon' ),

	// Reference: src/components/ProductDataTabsOptions.vue:334
	// Reference: src/components/WpWidgetBlockOptions.vue:183
	__( 'Heading Color', 'coming-soon' ),

	// Reference: src/components/ProductDataTabsOptions.vue:338
	__( 'Panel Padding', 'coming-soon' ),

	// Reference: src/components/ProductMetaOptions.vue:322
	__( 'View', 'coming-soon' ),

	// Reference: src/components/ProductMetaOptions.vue:323
	__( 'Table', 'coming-soon' ),

	// Reference: src/components/ProductMetaOptions.vue:324
	// Reference: src/components/ProductPriceOptions.vue:184
	// Reference: src/components/SocialProfilesOptions.vue:687
	__( 'Stacked', 'coming-soon' ),

	// Reference: src/components/ProductMetaOptions.vue:325
	__( 'Inline', 'coming-soon' ),

	// Reference: src/components/ProductPriceOptions.vue:183
	__( 'Sale Price', 'coming-soon' ),

	// Reference: src/components/ProductRelatedOptions.vue:622
	// Reference: src/components/UpsellsOptions.vue:622
	// Reference: src/components/WCCartOptions.vue:523
	// Reference: src/components/WCCheckoutOptions.vue:791
	// Reference: src/components/WCCustomProductsGridOptions.vue:1160
	// Reference: src/views/GlobalCSS.vue:1984
	__( 'Button Color', 'coming-soon' ),

	// Reference: src/components/ProductRelatedOptions.vue:650
	// Reference: src/components/UpsellsOptions.vue:650
	__( 'Posts Per Page', 'coming-soon' ),

	// Reference: src/components/ProductRelatedOptions.vue:653
	// Reference: src/components/UpsellsOptions.vue:653
	// Reference: src/components/WCCustomProductsGridOptions.vue:1191
	__( 'ID', 'coming-soon' ),

	// Reference: src/components/ProductRelatedOptions.vue:655
	// Reference: src/components/UpsellsOptions.vue:655
	// Reference: src/components/WCCustomProductsGridOptions.vue:1193
	__( 'Popularity', 'coming-soon' ),

	// Reference: src/components/ProductRelatedOptions.vue:656
	// Reference: src/components/UpsellsOptions.vue:656
	// Reference: src/components/WCCustomProductsGridOptions.vue:1194
	__( 'Random', 'coming-soon' ),

	// Reference: src/components/ProductRelatedOptions.vue:657
	// Reference: src/components/StarRatingOptions.vue:300
	// Reference: src/components/UpsellsOptions.vue:657
	// Reference: src/components/WCCustomProductsGridOptions.vue:1195
	__( 'Rating', 'coming-soon' ),

	// Reference: src/components/ProductRelatedOptions.vue:659
	// Reference: src/components/UpsellsOptions.vue:659
	// Reference: src/components/WCCustomProductsGridOptions.vue:1229
	__( 'Sale Badge Color', 'coming-soon' ),

	// Reference: src/components/ProgressBarOptions.vue:322
	__( 'Progress Bar', 'coming-soon' ),

	// Reference: src/components/ProgressBarOptions.vue:323
	__( 'Bar Text', 'coming-soon' ),

	// Reference: src/components/ProgressBarOptions.vue:324
	__( 'Percent', 'coming-soon' ),

	// Reference: src/components/ProgressBarOptions.vue:326
	__( 'My Text', 'coming-soon' ),

	// Reference: src/components/Row.vue:1056
	// Reference: src/components/Section.vue:668
	// Reference: src/views/BuilderView.vue:1053
	__( 'Drag a new block here', 'coming-soon' ),

	// Reference: src/components/Row.vue:1057
	// Reference: src/components/Section.vue:672
	// Reference: src/views/BuilderView.vue:1054
	// Reference: src/views/Layoutnav.vue:774
	__( 'Choose your layout:', 'coming-soon' ),

	// Reference: src/components/Row.vue:1058
	__( 'Enter a new block template name:', 'coming-soon' ),

	// Reference: src/components/Row.vue:1060
	// Reference: src/components/Section.vue:671
	// Reference: src/views/Layoutnav.vue:773
	// Reference: src/views/Setup.vue:1026
	__( 'Save Template', 'coming-soon' ),

	// Reference: src/components/RowOptions.vue:666
	__( 'Column Gutter', 'coming-soon' ),

	// Reference: src/components/RowOptions.vue:696
	__( 'Row Width', 'coming-soon' ),

	// Reference: src/components/RowOptions.vue:697
	// Reference: src/components/SectionOptions.vue:367
	__( 'Full Screen', 'coming-soon' ),

	// Reference: src/components/RowOptions.vue:698
	// Reference: src/components/SectionOptions.vue:368
	__( 'Fixed Width', 'coming-soon' ),

	// Reference: src/components/RowOptions.vue:699
	// Reference: src/components/SectionOptions.vue:369
	__( 'Content Width', 'coming-soon' ),

	// Reference: src/components/Section.vue:669
	// Reference: src/views/Layoutnav.vue:771
	__( 'Enter a new section template name:', 'coming-soon' ),

	// Reference: src/components/SectionOptions.vue:366
	__( 'Section Width', 'coming-soon' ),

	// Reference: src/components/SettingsLiteCTA.vue:166
	__( 'Powerful Page Editor', 'coming-soon' ),

	// Reference: src/components/SettingsLiteCTA.vue:168
	__( 'Email Marketing Integrations', 'coming-soon' ),

	// Reference: src/components/SettingsLiteCTA.vue:173
	__( 'Access Controls', 'coming-soon' ),

	// Reference: src/components/SettingsLiteCTA.vue:179
	__( 'Subscriber Management', 'coming-soon' ),

	// Reference: src/components/ShadowControl.vue:141
	__( 'Blur', 'coming-soon' ),

	// Reference: src/components/ShadowControl.vue:142
	__( 'Spread', 'coming-soon' ),

	// Reference: src/components/ShadowControl.vue:144
	__( 'Outline', 'coming-soon' ),

	// Reference: src/components/ShadowControl.vue:145
	__( 'Inset', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue:351
	__( 'Mountains', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue:352
	__( 'Drops', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue:353
	__( 'Clouds', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue:354
	__( 'Zigzag', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue:355
	__( 'Pyramids', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue:356
	__( 'Triangle', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue:357
	__( 'Triangle Asymmetrical', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue:358
	__( 'Tilt', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue:359
	__( 'Tilt Opacity', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue:360
	__( 'Fan Opacity', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue:361
	__( 'Curve', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue:362
	__( 'Curve Asymmetrical', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue:363
	__( 'Waves', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue:364
	__( 'Waves Brush', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue:365
	__( 'Waves Pattern', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue:366
	__( 'Arrow', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue:367
	__( 'Split', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue:368
	__( 'Book', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue:372
	__( 'Flip', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue:373
	__( 'Invert', 'coming-soon' ),

	// Reference: src/components/ShapeDividerControl.vue:374
	__( 'Bring to Front', 'coming-soon' ),

	// Reference: src/components/ShortcodeOptions.vue:140
	__( 'Shortcode', 'coming-soon' ),

	// Reference: src/components/ShortcodeOptions.vue:144
	__( 'Show Shortcode Preview', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue:671
	// Reference: src/components/SocialSharingOptions.vue:388
	__( 'Select a Type', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue:672
	// Reference: src/components/SocialSharingOptions.vue:389
	__( 'Facebook', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue:673
	// Reference: src/components/SocialSharingOptions.vue:390
	__( 'Twitter', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue:674
	// Reference: src/components/SocialSharingOptions.vue:391
	__( 'LinkedIn', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue:675
	// Reference: src/components/SocialSharingOptions.vue:392
	__( 'Pinterest', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue:676
	// Reference: src/components/VideoOptions.vue:234
	__( 'YouTube', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue:677
	__( 'Instagram', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue:678
	__( 'Snapchat', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue:679
	__( 'WordPress', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue:680
	__( 'Github', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue:681
	__( 'SoundCloud', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue:682
	__( 'RSS', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue:684
	__( 'URL (Include https:// for web links)', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue:694
	__( 'Icon Padding', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue:703
	__( 'Phone', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue:705
	__( 'Discord', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue:706
	__( 'Telegram', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue:707
	__( 'Facebook Messenger', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue:708
	__( 'Slack', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue:709
	__( 'Vimeo', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue:710
	__( 'Weibo', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue:711
	__( 'Whatsapp', 'coming-soon' ),

	// Reference: src/components/SocialProfilesOptions.vue:712
	__( 'TikTok', 'coming-soon' ),

	// Reference: src/components/SocialSharingOptions.vue:385
	__( 'Social Sharing', 'coming-soon' ),

	// Reference: src/components/SocialSharingOptions.vue:386
	__( 'Add New Share', 'coming-soon' ),

	// Reference: src/components/SocialSharingOptions.vue:394
	__( 'Tweet Text', 'coming-soon' ),

	// Reference: src/components/SpacerOptions.vue:67
	__( 'Spacer', 'coming-soon' ),

	// Reference: src/components/StarRatingOptions.vue:297
	__( 'Star Rating', 'coming-soon' ),

	// Reference: src/components/StarRatingOptions.vue:299
	__( 'Scale', 'coming-soon' ),

	// Reference: src/components/StarRatingOptions.vue:304
	__( 'Star Color', 'coming-soon' ),

	// Reference: src/components/StarRatingOptions.vue:306
	__( 'Empty Star Color', 'coming-soon' ),

	// Reference: src/components/TemplatetagOptions.vue:120
	__( 'Templatetag', 'coming-soon' ),

	// Reference: src/components/TemplatetagOptions.vue:124
	__( 'Show Templatetag Preview', 'coming-soon' ),

	// Reference: src/components/TemplatetagOptions.vue:125
	__( 'Select Type', 'coming-soon' ),

	// Reference: src/components/TestimonialOptions.vue:546
	__( 'Add Testimonial', 'coming-soon' ),

	// Reference: src/components/TestimonialOptions.vue:549
	__( 'Navigation Color Mode', 'coming-soon' ),

	// Reference: src/components/TestimonialOptions.vue:550
	__( 'Dark', 'coming-soon' ),

	// Reference: src/components/TestimonialOptions.vue:551
	__( 'Light', 'coming-soon' ),

	// Reference: src/components/TestimonialOptions.vue:554
	__( 'AutoPlay', 'coming-soon' ),

	// Reference: src/components/TestimonialOptions.vue:555
	__( 'Pause On Hover', 'coming-soon' ),

	// Reference: src/components/TestimonialOptions.vue:556
	__( 'Autoplay Speed', 'coming-soon' ),

	// Reference: src/components/TestimonialOptions.vue:557
	__( 'seconds', 'coming-soon' ),

	// Reference: src/components/TestimonialOptions.vue:558
	__( 'Enable Comment Bubble', 'coming-soon' ),

	// Reference: src/components/TestimonialOptions.vue:559
	__( 'Bubble Color', 'coming-soon' ),

	// Reference: src/components/TextOptions.vue:393
	__( 'Visual Editor', 'coming-soon' ),

	// Reference: src/components/TextOptions.vue:394
	__( 'Edit HTML', 'coming-soon' ),

	// Reference: src/components/TypographyControl.vue:274
	__( 'Typography', 'coming-soon' ),

	// Reference: src/components/TypographyControl.vue:279
	__( 'Line Height', 'coming-soon' ),

	// Reference: src/components/TypographyControl.vue:280
	__( 'Letter Spacing', 'coming-soon' ),

	// Reference: src/components/TypographyControl.vue:283
	__( 'Letter Case', 'coming-soon' ),

	// Reference: src/components/VideoOptions.vue:231
	__( 'Video', 'coming-soon' ),

	// Reference: src/components/VideoOptions.vue:236
	// Reference: src/views/GlobalCSS.vue:1899
	// Reference: src/views/SetupDesign-Lite.vue:736
	__( 'YouTube URL', 'coming-soon' ),

	// Reference: src/components/VideoOptions.vue:237
	__( 'Custom Video Code', 'coming-soon' ),

	// Reference: src/components/WCAddToCartOptions.vue:731
	__( 'Product ID', 'coming-soon' ),

	// Reference: src/components/WCAddToCartOptions.vue:732
	__( 'Direct To Checkout', 'coming-soon' ),

	// Reference: src/components/WCCartOptions.vue:497
	// Reference: src/components/WCCheckoutOptions.vue:765
	// Reference: src/components/WCCustomProductsGridOptions.vue:1078
	// Reference: src/views/GlobalCSS.vue:1912
	// Reference: src/views/SetupDesign-Lite.vue:746
	__( 'Headers', 'coming-soon' ),

	// Reference: src/components/WCCartOptions.vue:500
	// Reference: src/components/WCCheckoutOptions.vue:768
	// Reference: src/components/WCCustomProductsGridOptions.vue:1081
	__( 'Alerts', 'coming-soon' ),

	// Reference: src/components/WCCartOptions.vue:501
	// Reference: src/components/WCCheckoutOptions.vue:769
	// Reference: src/components/WCCustomProductsGridOptions.vue:1082
	__( 'Cart', 'coming-soon' ),

	// Reference: src/components/WCCartOptions.vue:502
	// Reference: src/components/WCCheckoutOptions.vue:770
	// Reference: src/components/WCCustomProductsGridOptions.vue:1083
	__( 'Payment Section', 'coming-soon' ),

	// Reference: src/components/WCCartOptions.vue:512
	// Reference: src/components/WCCheckoutOptions.vue:780
	// Reference: src/components/WCCustomProductsGridOptions.vue:1093
	__( 'One Column', 'coming-soon' ),

	// Reference: src/components/WCCartOptions.vue:513
	// Reference: src/components/WCCheckoutOptions.vue:781
	// Reference: src/components/WCCustomProductsGridOptions.vue:1094
	__( 'Two Column', 'coming-soon' ),

	// Reference: src/components/WCCartOptions.vue:530
	// Reference: src/components/WCCheckoutOptions.vue:798
	// Reference: src/components/WCCustomProductsGridOptions.vue:1111
	__( 'Info Highlight Color', 'coming-soon' ),

	// Reference: src/components/WCCartOptions.vue:531
	// Reference: src/components/WCCheckoutOptions.vue:799
	// Reference: src/components/WCCustomProductsGridOptions.vue:1112
	__( 'Error Highlight Color', 'coming-soon' ),

	// Reference: src/components/WCCartOptions.vue:532
	// Reference: src/components/WCCheckoutOptions.vue:800
	// Reference: src/components/WCCustomProductsGridOptions.vue:1113
	__( 'Success Highlight Color', 'coming-soon' ),

	// Reference: src/components/WCCartOptions.vue:533
	// Reference: src/components/WCCheckoutOptions.vue:801
	// Reference: src/components/WCCustomProductsGridOptions.vue:1114
	__( 'Cart Border Color', 'coming-soon' ),

	// Reference: src/components/WCCartOptions.vue:534
	// Reference: src/components/WCCheckoutOptions.vue:802
	// Reference: src/components/WCCustomProductsGridOptions.vue:1115
	__( 'Cart Border Width', 'coming-soon' ),

	// Reference: src/components/WCCartOptions.vue:539
	// Reference: src/components/WCCheckoutOptions.vue:807
	// Reference: src/components/WCCustomProductsGridOptions.vue:1120
	__( 'Header Background Color', 'coming-soon' ),

	// Reference: src/components/WCCartOptions.vue:540
	// Reference: src/components/WCCheckoutOptions.vue:808
	// Reference: src/components/WCCustomProductsGridOptions.vue:1121
	__( 'Header Font Family', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1124
	__( 'Query', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1127
	__( 'All Products', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1132
	__( 'Featured Products', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1133
	__( 'Sale Products', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1134
	__( 'Best Selling Products', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1135
	__( 'Recent Products', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1136
	__( 'Top Rated Products', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1137
	__( 'Include', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1138
	__( 'Exclude', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1139
	__( 'Include By', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1140
	__( 'Exclude By', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1141
	__( 'Term', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1188
	__( 'Limit', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1197
	__( 'Select By SKU', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1198
	__( '- Select SKU(s) -', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1199
	__( 'Select By Category', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1201
	__( 'Select By Tags', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1202
	__( '- Select Tags -', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1203
	__( 'Select By Group', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1204
	__( '- Select Group -', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1205
	__( 'On Sale', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1206
	__( 'Best Selling', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1207
	__( 'Top Rated', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1208
	__( 'Query By Attribute', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1209
	__( '- Select Attribute -', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1210
	__( '- Select Attribute Terms -', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1211
	__( 'Include Selected Terms', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1212
	__( 'Exclude Selected Terms', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1213
	__( 'Include Selected Tags', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1214
	__( 'Exclude Selected Tags', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1216
	__( 'Exclude Selected Categories', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1217
	__( 'Select By Visibility', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1218
	__( '- Select Product Visibility -', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1220
	__( 'Catalog', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1223
	__( 'Featured', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1224
	__( 'Custom Query', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1225
	__( 'Select By ID', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1226
	__( '- Select ID(s) -', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1227
	__( 'Show Items Count', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1228
	__( 'Show Order By', 'coming-soon' ),

	// Reference: src/components/WCCustomProductsGridOptions.vue:1230
	__( 'Archive Products', 'coming-soon' ),

	// Reference: src/components/WpWidgetBlock-Lite.vue:52
	__( '(Click \'Apply\' on the Widget Settings to see changes)', 'coming-soon' ),

	// Reference: src/components/WpWidgetBlockOptions.vue:188
	__( 'Widget Settings', 'coming-soon' ),

	// Reference: src/components/WpWidgetBlockOptions.vue:190
	__( 'Heading Bottom Margin', 'coming-soon' ),

	// Reference: src/mixins/helpers.js:1026
	__( 'Visit Docs&nbsp;<i class="fas fa-external-link-alt"></i>', 'coming-soon' ),

	// Reference: src/mixins/helpers.js:1052
	__( ' is a PRO Feature', 'coming-soon' ),

	// Reference: src/mixins/helpers.js:1056
	__( ' feature is not available on your plan. Please upgrade to the PRO plan to unlock all these awesome features.', 'coming-soon' ),

	// Reference: src/mixins/helpers.js:1070
	__( 'UPGRADE TO PRO', 'coming-soon' ),

	// Reference: src/mixins/helpers.js:1074
	__( '<strong>Bonus:</strong>&nbsp;SeedProd Lite users get a discount off the regular price, automatically applied at checkout.', 'coming-soon' ),

	// Reference: src/mixins/helpers.js:1087
	__( 'Thanks for your interest in SeedProd Lite!<br>If you have any questions or issues just <a href=\'https://www.seedprod.com/?contact=1\' target=\'_blank\'>let us know</a>.<br><br>After purchasing SeedProd Lite, you\'ll need to download and install the Pro version of the plugin, and then remove the free plugin. <br><br>(Don\'t worry, all your settings will be preserved.)', 'coming-soon' ),

	// Reference: src/mixins/helpers.js:1103
	__( 'Upgrade to PRO', 'coming-soon' ),

	// Reference: src/mixins/helpers.js:1104
	__( 'Increase traffic, engagement, and get more email subscribers. Click below to learn more about all our awesome features.', 'coming-soon' ),

	// Reference: src/mixins/helpers.js:1110
	__( 'Upgrade to Unlock ', 'coming-soon' ),

	// Reference: src/mixins/helpers.js:1112
	__( 'We\'re sorry, the ', 'coming-soon' ),

	// Reference: src/mixins/helpers.js:1114
	__( ' feature is not available on your plan. Please upgrade your plan to unlock this feature and more!', 'coming-soon' ),

	// Reference: src/mixins/helpers.js:1130
	__( 'Upgrade with just a click of a button!', 'coming-soon' ),

	// Reference: src/mixins/helpers.js:895
	// Reference: src/views/SectionTemplateOptions-Lite.vue:475
	// Reference: src/views/TemplateChooser-Lite.vue:1397
	__( 'Are you sure you want to delete?', 'coming-soon' ),

	// Reference: src/mixins/helpers.js:904
	// Reference: src/views/SectionTemplateOptions-Lite.vue:484
	// Reference: src/views/TemplateChooser-Lite.vue:1406
	__( 'Yes, delete it!', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1893
	// Reference: src/views/SetupBlockOptions-Lite.vue:1171
	// Reference: src/views/SetupDesign-Lite.vue:730
	__( 'Editing:', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1894
	__( 'Global CSS Settings', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1895
	// Reference: src/views/SetupDesign-Lite.vue:732
	__( 'Header Font', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1896
	// Reference: src/views/SetupDesign-Lite.vue:733
	__( 'Body Text Font', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1898
	__( 'Use Video Background', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1900
	// Reference: src/views/SetupDesign-Lite.vue:737
	__( 'The video background will not be displayed on mobile devices or in the editor preview.', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1904
	// Reference: src/views/SetupDesign-Lite.vue:738
	__( 'Play on auto-loop', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1905
	// Reference: src/views/SetupDesign-Lite.vue:739
	__( 'Enter your custom css below', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1906
	// Reference: src/views/SetupDesign-Lite.vue:740
	__( 'Edit Custom CSS', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1909
	// Reference: src/views/SetupDesign-Lite.vue:743
	__( 'Font Themes Library', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1910
	// Reference: src/views/SetupDesign-Lite.vue:744
	__( 'Search colors...', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1911
	// Reference: src/views/SetupDesign-Lite.vue:745
	__( 'Search fonts...', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1915
	// Reference: src/views/SetupDesign-Lite.vue:749
	__( 'Links', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1917
	// Reference: src/views/SetupDesign-Lite.vue:751
	__( 'Font Themes', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1918
	// Reference: src/views/SetupDesign-Lite.vue:752
	__( 'Color Palettes', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1920
	// Reference: src/views/SetupDesign-Lite.vue:754
	__( 'Fonts', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1923
	// Reference: src/views/SetupDesign-Lite.vue:757
	__( 'Custom CSS', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1924
	// Reference: src/views/SetupDesign-Lite.vue:758
	__( 'All Palettes', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1925
	// Reference: src/views/SetupDesign-Lite.vue:759
	__( 'All Themes', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1926
	// Reference: src/views/SetupDesign-Lite.vue:760
	__( 'Serif', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1927
	// Reference: src/views/SetupDesign-Lite.vue:761
	__( 'Sans Serif', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1928
	// Reference: src/views/SetupDesign-Lite.vue:762
	__( 'Background Slideshow', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1929
	// Reference: src/views/SetupDesign-Lite.vue:763
	__( 'Slideshow Images', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1930
	// Reference: src/views/SetupDesign-Lite.vue:764
	__( 'Add New Slide', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1931
	// Reference: src/views/SetupDesign-Lite.vue:765
	__( 'The background slideshow will not be shown in the editor preview. The slides will only be displayed in the live preview.', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1936
	__( 'Add Custom Color', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1937
	__( 'Body Text Color', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1938
	__( 'Show H1 - H6 Settings', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1940
	__( 'H1 ', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1941
	__( 'H1 Color', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1942
	__( 'H2 ', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1943
	__( 'H2 Color', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1944
	__( 'H3 ', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1945
	__( 'H3 Color', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1946
	__( 'H4 ', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1947
	__( 'H4 Color', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1948
	__( 'H5 ', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1949
	__( 'H5 Color', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1950
	__( 'H6 ', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1951
	__( 'H6 Color', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1952
	__( 'Body Text', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1953
	__( 'Desktop BG', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1954
	__( 'Mobile BG', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1959
	__( 'Row Default Max Width', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1961
	__( 'Forms', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1964
	__( 'Field', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1968
	__( 'Field Border Style', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1973
	__( 'Field Padding', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1974
	__( 'Header Default Bottom Margin', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1978
	__( 'Paragraph Default Bottom Margin', 'coming-soon' ),

	// Reference: src/views/GlobalCSS.vue:1982
	__( 'Label Default Bottom Margin', 'coming-soon' ),

	// Reference: src/views/Layoutnav.vue:766
	__( 'Expand All', 'coming-soon' ),

	// Reference: src/views/Layoutnav.vue:767
	__( 'Collapse All', 'coming-soon' ),

	// Reference: src/views/Layoutnav.vue:768
	__( 'Section', 'coming-soon' ),

	// Reference: src/views/Revisions.vue:62
	__( 'Loading Revisons', 'coming-soon' ),

	// Reference: src/views/Revisions.vue:63
	__( 'Click to preview version:', 'coming-soon' ),

	// Reference: src/views/Revisions.vue:64
	__( 'Current Version', 'coming-soon' ),

	// Reference: src/views/Revisions.vue:65
	__( 'by', 'coming-soon' ),

	// Reference: src/views/Revisions.vue:66
	__( 'There are no revisons to show.', 'coming-soon' ),

	// Reference: src/views/Revisions.vue:67
	__( 'ago', 'coming-soon' ),

	// Reference: src/views/SectionTemplateOptions-Lite.vue:432
	__( 'Choose This Section', 'coming-soon' ),

	// Reference: src/views/SectionTemplateOptions-Lite.vue:535
	// Reference: src/views/TemplateChooser-Lite.vue:1455
	__( 'Deleted!', 'coming-soon' ),

	// Reference: src/views/SectionTemplates-Lite.vue:100
	__( 'All Sections', 'coming-soon' ),

	// Reference: src/views/SectionTemplates-Lite.vue:101
	__( 'Favorites', 'coming-soon' ),

	// Reference: src/views/SectionTemplates-Lite.vue:102
	__( 'Categories:', 'coming-soon' ),

	// Reference: src/views/SectionTemplates-Lite.vue:98
	// Reference: src/views/SetupBlockOptions-Lite.vue:1166
	__( 'Blocks', 'coming-soon' ),

	// Reference: src/views/SectionTemplates-Lite.vue:99
	// Reference: src/views/SetupBlockOptions-Lite.vue:1167
	__( 'Sections', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Lite.vue:320
	// Reference: src/views/SetupSettings.vue:248
	__( 'Access Control', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Lite.vue:321
	__( 'Exclude Default:', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Lite.vue:324
	__( 'By default we exclude urls with the terms: login, admin, dashboard and account to prevent lockouts.', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Lite.vue:325
	__( 'Bypass Cookie:', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Lite.vue:326
	__( 'Use cookies instead of creating a WordPress user for the bypass. Note: this may not work on sites that are cached. Learn More', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Lite.vue:327
	__( 'Bypass URL:', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Lite.vue:328
	__( 'Bypass URL Expires:', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Lite.vue:329
	__( 'Access by IP:', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Lite.vue:330
	__( 'Access by Role:', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Lite.vue:331
	__( 'By default anyone logged in will see the regular website and not the coming soon page. To override this select Roles that will be given access to see the regular website.', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Lite.vue:332
	__( 'Include/Exclude URLs:', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Lite.vue:333
	__( 'Show on the Entire Website', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Lite.vue:334
	__( 'Show on the Entire Website except for the Blog', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Lite.vue:335
	__( 'Show on the Home Page Only', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Lite.vue:336
	__( 'Include URLs', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Lite.vue:337
	__( 'Exclude URLs', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Lite.vue:338
	__( 'By default the Coming Soon/Maintenance page is shown on every page. Use the \'Show on the Home Page Only\' option to only show on the home page. Alternatively Include or Exclude URLs.', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Lite.vue:339
	__( 'Enter a phrase above and give your visitors a secret url that will allow them to bypass the Coming Soon page.', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Lite.vue:340
	__( 'After the bypass url expires the user will need to revisit the bypass url to regain access.', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Lite.vue:341
	__( 'One IP Address per line', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Lite.vue:342
	__( 'All visitors from certain IP\'s to bypass the Coming Soon page.', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Lite.vue:343
	__( 'Put each IP on it\'s own line. Your current IP is:', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Lite.vue:344
	__( 'Add Role', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Lite.vue:345
	__( 'Include certain urls to display the Coming Soon or Maintenance Page.', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Lite.vue:346
	__( 'One per line. You may also enter a page or post id.', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Lite.vue:347
	__( 'Exclude certain urls to display the Coming Soon or Maintenance Page.', 'coming-soon' ),

	// Reference: src/views/SettingsAccess-Lite.vue:348
	__( 'Example: /about-us/', 'coming-soon' ),

	// Reference: src/views/SettingsAnalytics.vue:114
	// Reference: src/views/SetupSettings.vue:250
	__( 'Analytics', 'coming-soon' ),

	// Reference: src/views/SettingsAnalytics.vue:115
	__( 'Your Analytics settings are being managed by:', 'coming-soon' ),

	// Reference: src/views/SettingsAnalytics.vue:119
	__( 'Edit Analytics Settings', 'coming-soon' ),

	// Reference: src/views/SettingsAnalytics.vue:120
	// Reference: src/views/SettingsSEO.vue:229
	__( 'Your SEO settings are being managed by:', 'coming-soon' ),

	// Reference: src/views/SettingsAnalytics.vue:124
	__( 'Install Google Analytics plugin:', 'coming-soon' ),

	// Reference: src/views/SettingsAnalytics.vue:128
	__( 'Install MonsterInsights', 'coming-soon' ),

	// Reference: src/views/SettingsAnalytics.vue:129
	__( 'Activate MonsterInsights', 'coming-soon' ),

	// Reference: src/views/SettingsAnalytics.vue:130
	__( 'Install Analytics plugin:', 'coming-soon' ),

	// Reference: src/views/SettingsDomain.vue:120
	// Reference: src/views/SetupSettings.vue:252
	__( 'Custom Domain', 'coming-soon' ),

	// Reference: src/views/SettingsDomain.vue:121
	__( 'Custom Domain:', 'coming-soon' ),

	// Reference: src/views/SettingsDomain.vue:122
	__( 'OFF', 'coming-soon' ),

	// Reference: src/views/SettingsDomain.vue:123
	__( 'ON', 'coming-soon' ),

	// Reference: src/views/SettingsDomain.vue:124
	__( 'Domain Name:', 'coming-soon' ),

	// Reference: src/views/SettingsDomain.vue:125
	__( 'Please enter your domain.', 'coming-soon' ),

	// Reference: src/views/SettingsDomain.vue:126
	__( 'Click here to learn more', 'coming-soon' ),

	// Reference: src/views/SettingsDomain.vue:127
	__( 'how to map your custom domain.', 'coming-soon' ),

	// Reference: src/views/SettingsDomain.vue:128
	__( 'Force HTTPS', 'coming-soon' ),

	// Reference: src/views/SettingsDomain.vue:129
	__( 'Only enable this if you have an SSL certificate installed and you wish to redirect users to https://', 'coming-soon' ),

	// Reference: src/views/SettingsDomain.vue:130
	__( 'Please enter a valid URL that will be pointed to this landing page, such as', 'coming-soon' ),

	// Reference: src/views/SettingsDomain.vue:131
	__( 'It should look something like, \'mynewdomain.com\' or \'mynewdomain.com/coming-soon\'', 'coming-soon' ),

	// Reference: src/views/SettingsDomain.vue:132
	__( 'You can leave out the \'http://\'. If you are using \'https://\', turn on Force HTTPS below.', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue:218
	__( 'Page Title:', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue:219
	// Reference: src/views/TemplateChooser-Lite.vue:1224
	__( 'Page URL:', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue:220
	__( 'Page Status:', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue:221
	__( 'Draft', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue:222
	// Reference: src/views/Setup.vue:1021
	__( 'Publish', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue:223
	__( '"Powered by SeedProd"', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue:226
	__( 'Choose New Template:', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue:227
	__( 'Redirect Mode', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue:228
	__( 'Redirect URL: A temporary redirect (302 status) will be created to the url entered.', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue:229
	__( 'Enable', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue:230
	__( 'Redirect URL: A permanent redirect (301 status) will be created to the url entered.', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue:232
	__( 'SeedProd Link', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue:233
	__( 'Enter Your Affiliate URL and Make Money with SeedProd', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue:234
	__( 'Join our affiliate program', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue:235
	__( 'and get a 20% commission on all sales generated from your powered by link.', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue:236
	__( 'Isolation Mode', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue:237
	__( 'Redirect the Default Login Page', 'coming-soon' ),

	// Reference: src/views/SettingsGeneral.vue:238
	__( 'Facebook App ID:', 'coming-soon' ),

	// Reference: src/views/SettingsSEO.vue:228
	// Reference: src/views/SetupSettings.vue:249
	__( 'SEO', 'coming-soon' ),

	// Reference: src/views/SettingsSEO.vue:233
	__( 'Yoast SEO', 'coming-soon' ),

	// Reference: src/views/SettingsSEO.vue:234
	__( 'Edit this page\'s SEO Settings', 'coming-soon' ),

	// Reference: src/views/SettingsSEO.vue:239
	__( 'Install All In One SEO', 'coming-soon' ),

	// Reference: src/views/SettingsSEO.vue:240
	__( 'Activate All in One SEO', 'coming-soon' ),

	// Reference: src/views/SettingsSEO.vue:241
	__( 'Install SEO plugin:', 'coming-soon' ),

	// Reference: src/views/SettingsScripts.vue:56
	// Reference: src/views/SetupSettings.vue:251
	__( 'Scripts', 'coming-soon' ),

	// Reference: src/views/SettingsScripts.vue:57
	__( 'Header Scripts:', 'coming-soon' ),

	// Reference: src/views/SettingsScripts.vue:58
	__( 'This code will be rendered before the closing &lt;/head&gt; tag.', 'coming-soon' ),

	// Reference: src/views/SettingsScripts.vue:62
	__( 'Footer Scripts:', 'coming-soon' ),

	// Reference: src/views/SettingsScripts.vue:63
	__( 'The code will be rendered before the closing &lt;/body&gt; tag.', 'coming-soon' ),

	// Reference: src/views/SettingsScripts.vue:67
	__( 'Body Scripts:', 'coming-soon' ),

	// Reference: src/views/SettingsScripts.vue:68
	__( 'The code will be rendered after the &lt;body&gt; tag.', 'coming-soon' ),

	// Reference: src/views/SettingsScripts.vue:72
	__( 'You do not have the proper WordPress permissions to add scripts.', 'coming-soon' ),

	// Reference: src/views/Setup.vue:1010
	__( 'Design', 'coming-soon' ),

	// Reference: src/views/Setup.vue:1011
	__( 'Connect', 'coming-soon' ),

	// Reference: src/views/Setup.vue:1012
	__( 'Page Settings', 'coming-soon' ),

	// Reference: src/views/Setup.vue:1013
	__( 'You have unsaved changes. Are you sure you want to lose these changes?', 'coming-soon' ),

	// Reference: src/views/Setup.vue:1014
	__( 'Exit Without Saving', 'coming-soon' ),

	// Reference: src/views/Setup.vue:1015
	__( 'template has been saved!', 'coming-soon' ),

	// Reference: src/views/Setup.vue:1016
	__( 'You can find it in your template library when you create a new landing page.', 'coming-soon' ),

	// Reference: src/views/Setup.vue:1017
	__( 'Enter a new template name:', 'coming-soon' ),

	// Reference: src/views/Setup.vue:1019
	__( 'Your page has been published!', 'coming-soon' ),

	// Reference: src/views/Setup.vue:1022
	__( 'Unpublish', 'coming-soon' ),

	// Reference: src/views/Setup.vue:1023
	__( 'Schedule', 'coming-soon' ),

	// Reference: src/views/Setup.vue:1024
	__( 'Save as Template', 'coming-soon' ),

	// Reference: src/views/Setup.vue:1025
	__( 'Return to Page Editor', 'coming-soon' ),

	// Reference: src/views/Setup.vue:1027
	__( 'See Live Page', 'coming-soon' ),

	// Reference: src/views/Setup.vue:1028
	__( 'Save and Exit', 'coming-soon' ),

	// Reference: src/views/Setup.vue:1029
	__( 'Help', 'coming-soon' ),

	// Reference: src/views/Setup.vue:1030
	__( 'Save', 'coming-soon' ),

	// Reference: src/views/Setup.vue:1033
	__( 'You are about to leave this page and go to the Global CSS page. Continue?', 'coming-soon' ),

	// Reference: src/views/Setup.vue:1034
	__( 'This page is not active. Would you like to activate it now?', 'coming-soon' ),

	// Reference: src/views/Setup.vue:1035
	__( 'Yes, Activate', 'coming-soon' ),

	// Reference: src/views/Setup.vue:1036
	__( 'No, Close', 'coming-soon' ),

	// Reference: src/views/Setup.vue:1037
	__( 'Coming Soon Mode is not active. Would you like to activate it now and show this page to visitors?', 'coming-soon' ),

	// Reference: src/views/Setup.vue:1038
	__( 'Maintenance Mode is not active. Would you like to activate it now and show this page to visitors?', 'coming-soon' ),

	// Reference: src/views/Setup.vue:1039
	__( 'Note: This page will only be shown to users who are logged out. If you logged out and and do not see the correct page you may need to clear your site cache.', 'coming-soon' ),

	// Reference: src/views/Setup.vue:1040
	__( 'This page is not published. Would you like to publish it now?', 'coming-soon' ),

	// Reference: src/views/Setup.vue:1041
	__( 'Yes, Publish', 'coming-soon' ),

	// Reference: src/views/Setup.vue:1567
	__( 'Something has prevented the page from being saved.', 'coming-soon' ),

	// Reference: src/views/SetupBlockOptions-Lite.vue:1168
	__( 'Standard', 'coming-soon' ),

	// Reference: src/views/SetupBlockOptions-Lite.vue:1170
	__( 'Saved Blocks', 'coming-soon' ),

	// Reference: src/views/SetupBlockOptions-Lite.vue:1172
	__( 'Search blocks...', 'coming-soon' ),

	// Reference: src/views/SetupBlockOptions-Lite.vue:1174
	__( 'Widgets', 'coming-soon' ),

	// Reference: src/views/SetupDesign-Lite.vue:735
	__( 'Video Background', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Lite.vue:1205
	__( '&larr; Go Back', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Lite.vue:1206
	__( '&larr; Go to Dashboard', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Lite.vue:1207
	__( 'Choose a New Page Template', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Lite.vue:1211
	__( 'No Favorited Templates Found', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Lite.vue:1212
	__( 'No Saved Templates Found', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Lite.vue:1217
	__( 'Choose This Template', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Lite.vue:1218
	__( 'Enter your new page details', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Lite.vue:1219
	__( 'You can always change it later in Page Settings.', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Lite.vue:1223
	__( 'Page Name:', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Lite.vue:1225
	__( 'Save and Start Editing the Page', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Lite.vue:1234
	__( 'My Landing Page name goes here', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Lite.vue:1238
	__( 'You can favorite any template by clicking the heart icon under the page template.', 'coming-soon' ),

	// Reference: src/views/TemplateChooser-Lite.vue:1242
	__( 'You can save pages as templates in the builder. Any saved pages will be shown here.', 'coming-soon' )
);
/* THIS IS THE END OF THE GENERATED FILE */
